@@ -1,7 +1,7 @@
 #! /usr/bin/env perl
 
 #
-#   Copyright (C) Heinz-Josef Claes (2000-2013)
+#   Copyright (C) Heinz-Josef Claes (2000-2012)
 #                 hjclaes@web.de
 #   
 #   This program is free software: you can redistribute it and/or modify
@@ -159,12 +159,12 @@ multitail.pl - Read multiple log files. The log files can be written round.
 
 =head1 COPYRIGHT
 
-Copyright (c) 2001-2013 by Heinz-Josef Claes (see README)
+Copyright (c) 2001-2012 by Heinz-Josef Claes (see README)
 Published under the GNU General Public License or any later version
 
 =cut
 
-my $Help = join('', grep(!/^\s*$/, `pod2text "$0"`));
+my $Help = join('', grep(!/^\s*$/, `pod2text $0`));
 $Help = "cannot find pod2text, see documentation for details\n"
     unless $Help;
 
