@@ -1,7 +1,7 @@
 #! /usr/bin/env perl
 
 #
-#   Copyright (C) Dr. Heinz-Josef Claes (2009)
+#   Copyright (C) Dr. Heinz-Josef Claes (2012)
 #                 hjclaes@web.de
 #   
 #   This program is free software: you can redistribute it and/or modify
@@ -19,9 +19,6 @@
 #
 
 
-my $VERSION = '$Id$ ';
-push @VERSION, $VERSION;
-my ($VERSIONpName, $VERSIONsvnID) = $VERSION =~ /Id:\s+(\S+)\s+(\d+)/;
 $main::STOREBACKUPVERSION = undef;
 
 
@@ -111,16 +108,22 @@ my $checkSumFile = '.md5CheckSums';
 
 =head1 NAME
 
-storeBackupCheckBackup.pl - checks if a file in the backup is missing or corrupted
+storeBackupCheckBackup.pl - checks if a file in the backup is missing
+or corrupted
 
 =head1 SYNOPSIS
 
-	storeBackupCheckBackup.pl -b backupDir [-v level] [-p number]
-              [backupRoot . . .]
+	storeBackupCheckBackup.pl -c backupDir [-p number] [-i]
+	      [--logFile
+	       [--suppressTime] [-m maxFilelen]
+	       [[-n noOfOldFiles] | [--saveLogs]]
 
 =head1 DESCRIPTION
 
-This program calculates md5 sums from the files in the backup and compares
+The tool is intended to find files in the source that might have changed over
+time without the users interaction or knowledge, for example by bit rot.
+
+IT calculates md5 sums from the files in the backup and compares
 them with md5 sums stored by storeBackup.pl.
 It so will recognize, if a file in the backup is missing or currupted.
 It only checks plain files, not special files or symbolic links.
@@ -133,29 +136,58 @@ It only checks plain files, not special files or symbolic links.
 
     print configuration parameters and stop
 
-=item B<--backupDir> F<backupDir>, B<-b> F<backupDir>
+=item B<--checkDir>, B<-c>
 
-    top level directory of all backups
+    backup or top of backups to check
+
+=item B<--backupRoot>, B<-b>
+
+    root of storeBackup tree, normally not needed
 
 =item B<--verbose>, B<-v>
 
-    generate some extra messages
+    generate statistics
 
 =item B<--parJobs>, B<-p>
 
-    number of parallel jobs, default = choosen automaticly
+    number of parallel jobs, default = chosen automatically
 
-=item [backupRoot]
+=item B<--includeRenamedBackups>, B<-i>
 
-    Root directories of backups where to search relative
-    to backupDir. If no directories are specified, all
-    backups below backupDir are chosen.
+    include renamed backups into the check renamed backups must
+    follow the convention <backupDir>-<something>
+
+=item B<--logFile>, B<-l>
+
+    logFile, Default: stdout
+
+=item B<--suppressTime>
+
+    suppress output of time in logfile
+
+=item B<--maxFilelen>, B<-m>
+
+    maximal length of log file, default = 1e6
+
+=item B<--noOfOldFiles>, B<-n>
+
+    number of old log files, default = 5
+
+=item B<--saveLogs>
+
+    save log files with date and time instead of deleting the
+    old (with [-noOldFiles])
+
+=item B<--compressWith>
+
+    compress saved log files (e.g. with 'gzip -9').
+    default is 'bzip2'
 
 =back
 
 =head1 COPYRIGHT
 
-Copyright (c) 2008 by Heinz-Josef Claes (see README)
+Copyright (c) 2008-2012 by Heinz-Josef Claes (see README)
 Published under the GNU General Public License v3 or any later version
 
 =cut
@@ -164,14 +196,13 @@ my $Help = join('', grep(!/^\s*$/, `pod2text $0`));
 $Help = "cannot find pod2text, see documentation for details\n"
     unless $Help;
 
-&printVersions(\@ARGV, '-V');
+&printVersion(\@ARGV, '-V');
 
 my $CheckPar =
-    CheckParam->new('-allowLists' => 'yes',
-		    '-list' => [Option->new('-name' => 'backupDir',
-					    '-cl_option' => '-b',
-					    '-cl_alias' => '--backupDir',
-					    '-cf_key' => 'backupDir',
+    CheckParam->new('-allowLists' => 'no',
+		    '-list' => [Option->new('-name' => 'checkBackup',
+					    '-cl_option' => '-c',
+					    '-cl_alias' => '--checkDir',
 					    '-param' => 'yes'),
 				Option->new('-name' => 'verbose',
 					    '-cl_option' => '-v',
@@ -182,7 +213,39 @@ my $CheckPar =
 					    '-param' => 'yes',
 					    '-pattern' => '\A[1-9]\d*\Z'),
 				Option->new('-name' => 'print',
-					    '-cl_option' => '--print')
+					    '-cl_option' => '--print'),
+				Option->new('-name' => 'includeRenamedBackups',
+					    '-cl_option' => '-i',
+					    '-cl_alias' =>
+					    '--includeRenamedBackups'),
+				Option->new('-name' => 'logFile',
+					    '-cl_option' => '-l',
+					    '-cl_alias' => '--logFile',
+					    '-param' => 'yes',
+					    '-only_if' => 'not [interactive]'),
+				Option->new('-name' => 'suppressTime',
+					    '-cl_option' => '--suppressTime'),
+				Option->new('-name' => 'maxFilelen',
+					    '-cl_option' => '-m',
+					    '-cl_alias' => '--maxFilelen',
+					    '-default' => 1e6,
+					    '-pattern' => '\A[e\d]+\Z',
+                                            '-only_if' =>'[logFile]'),
+				Option->new('-name' => 'noOfOldFiles',
+					    '-cl_option' => '-n',
+					    '-cl_alias' => '--noOfOldFiles',
+					    '-default' => '5',
+					    '-pattern' => '\A\d+\Z',
+                                            '-only_if' =>"[logFile]"),
+                                Option->new('-name' => 'saveLogs',
+					    '-cl_option' => '--saveLogs',
+                                            '-default' => 'no',
+                                            '-only_if' => '[logFile]'),
+                                Option->new('-name' => 'compressWith',
+					    '-cl_option' => '--compressWith',
+					    '-quoteEval' => 'yes',
+                                            '-default' => 'bzip2',
+                                            '-only_if' =>'[logFile]')
 		    ]
     );
 
@@ -193,10 +256,19 @@ $CheckPar->check('-argv' => \@ARGV,
 
 # Auswertung der Parameter
 my $print = $CheckPar->getOptWithoutPar('print');
-my $backupDir = $CheckPar->getOptWithPar('backupDir');
+my $backupDir = $CheckPar->getOptWithPar('checkBackup');
 my $parJobs = $CheckPar->getOptWithPar('parJobs');
 my $verbose = $CheckPar->getOptWithoutPar('verbose');
-my (@backupRoot) = $CheckPar->getListPar();
+my $includeRenamedBackups =
+    $CheckPar->getOptWithoutPar('includeRenamedBackups');
+my $logFile = $CheckPar->getOptWithPar('logFile');
+my $withTime = not $CheckPar->getOptWithoutPar('suppressTime');
+$withTime = $withTime ? 'yes' : 'no';
+my $maxFilelen = $CheckPar->getOptWithPar('maxFilelen');
+my $noOfOldFiles = $CheckPar->getOptWithPar('noOfOldFiles');
+my $saveLogs = $CheckPar->getOptWithPar('saveLogs');
+$saveLogs = $saveLogs ? 'yes' : 'no';
+my $compressWith = $CheckPar->getOptWithPar('compressWith');
 
 
 unless ($parJobs)
@@ -216,77 +288,84 @@ unless ($parJobs)
     $parJobs = 3 if $parJobs < 3;
 }
 
-
-
 if ($print)
 {
     $CheckPar->print();
     exit 0;
 }
 
-my $prLog = printLog->new('-kind' => ['I:INFO', 'W:WARNING', 'E:ERROR',
-				      'S:STATISTIC', 'D:DEBUG', 'V:VERSION']);
 
-#$prLog->print('-kind' => 'V',
-#	      '-str' => ["$VERSIONpName, $main::STOREBACKUPVERSION, " .
-#			 "build $VERSIONsvnID"]);
+my (@par) = ();
+if (defined $logFile)
+{
+    push @par, ('-file' => $logFile,
+		'-multiprint' => 'yes');
+}
+else
+{
+    push @par, ('-filedescriptor', *STDOUT);
+}
+
+my ($prLogKind) = ['A:BEGIN',
+		   'Z:END',
+		   'V:VERSION',
+		   'I:INFO',
+		   'W:WARNING',
+		   'E:ERROR',
+		   'S:STATISTIC',
+		   'D:DEBUG'];
+my $printLog = printLog->new('-kind' => $prLogKind,
+			     @par,
+			     '-withTime' => $withTime,
+			     '-maxFilelen' => $maxFilelen,
+			     '-noOfOldFiles' => $noOfOldFiles,
+			     '-saveLogs' => $saveLogs,
+			     '-compressWith' => $compressWith);
+
+my $prLog = printLogMultiple->new('-prLogs' => [$printLog]);
+
+$prLog->fork($req);
+
 
 $prLog->print('-kind' => 'E',
 	      '-str' => ["missing parameter backupDir\n$Help"],
 	      '-exit' => 1)
     unless defined $backupDir;
+$backupDir =~ s/\/+\Z//;      # remove / at the end
 $prLog->print('-kind' => 'E',
 	      '-str' => ["backupDir directory <$backupDir> does not exist " .
 	      "or is not accesible"],
 	      '-exit' => 1)
     unless -r $backupDir;
 
+$prLog->print('-kind' => 'A',
+	      '-str' => ["checking backups in <" .
+			 ::absolutePath($backupDir) . ">"]);
+$prLog->print('-kind' => 'V',
+	      '-str' => ["storeBackupCheckBackup.pl, $main::STOREBACKUPVERSION"]);
+
+if (-l $backupDir)
+{
+    my $newLink = ::absolutePath($backupDir);
+    $prLog->print('-kind' => 'I',
+		  '-str' =>
+		  ["replacing symlink <$backupDir> with <$newLink>"]);
+    $backupDir = $newLink;
+}
+
 
 my $allLinks = lateLinks->new('-dirs' => [$backupDir],
 			      '-kind' => 'recursiveSearch',
 			      '-verbose' => 0,
-			      '-prLog' => $prLog);
+			      '-prLog' => $prLog,
+			      '-includeRenamedBackupDirs' =>
+			      $includeRenamedBackups);
 
 my $allStbuDirs = $allLinks->getAllStoreBackupDirs();
 
 
 # filter the relevant backups
-my (@dirsToCheck) = ();
-if (@backupRoot)
-{
-    my $d;
-    foreach $d (@backupRoot)
-    {
-	unless ($d =~ m#\A/#)
-	{
-	    $d = "$backupDir/$d";
-	}
-	$prLog->print('-kind' => 'E',
-		      '-str' => ["directory <$d> does not exist " .
-				 "or is not accesible"],
-		      '-exit' => 1)
-	    unless -r $d;
-	$d = &::absolutePath($d);
-	$prLog->print('-kind' => 'E',
-		      '-str' => ["directory <$d> is not a subdirectory " .
-				 "of backupDir <$backupDir>"],
-		      '-exit' => 1)
-	    unless $d =~ /\A$backupDir/;
-
-	# now get all dirs from @$allStbuDirs below $d
-	my $a;
-	foreach $a (@$allStbuDirs)
-	{
-	    push @dirsToCheck, $a
-		if $a =~ /\A$d\//s or $a =~ /\A$d\z/s;
-	}
-    }
-    (@dirsToCheck) = sort { $a cmp $b } @dirsToCheck;
-}
-else
-{
-    (@dirsToCheck) = sort { $a cmp $b } @$allStbuDirs;
-}
+my (@dirsToCheck) = sort { $a cmp $b } @$allStbuDirs;
 
 
 $prLog->print('-kind' => 'E',
@@ -295,10 +374,38 @@ $prLog->print('-kind' => 'E',
     unless @dirsToCheck;
 
 {
-    my (@out, $d);
-    foreach $d (@dirsToCheck)
+    my (@out, @d, $d);
+    (@d) = (@dirsToCheck);
+    (@dirsToCheck) = ();
+    foreach $d (@d)
     {
+	unless (-r "$d/$checkSumFile" or
+		-r "$d/$checkSumFile.bz2")
+	{
+	    $prLog->print('-kind' => 'E',
+			  '-str' => ["no readable <$checkSumFile> in " .
+				     "<$d> ... skipping"]);
+	    next;
+	}
+	if (-e "$d/$checkSumFile.notFinished")
+	{
+	    $prLog->print('-kind' => 'E',
+			  '-str' => ["backup <$d> not finished" .
+				     " ... skipping"]);
+	    next;
+	}
+	if (-e "$d/.storeBackupLinks/linkFile.bz2")
+	{
+	    $prLog->print('-kind' => 'E',
+			  '-str' =>
+			  ["backup <$d> needs run of " .
+			   "~/svn/stbu/bin/storeBackupUpdateBackup.pl" .
+			   " ... skipping"]);
+	    next;
+	}
+
 	push @out, "  $d";
+	push @dirsToCheck, $d;
     }
     $prLog->print('-kind' => 'I',
 		  '-str' => ["backup directories to check", @out]);
@@ -313,26 +420,55 @@ my ($meta, $postfix, $uncompr, @uncomprPar);
 my $dirToCheck = undef;
 my $jobToDo = 1;
 my $parForkToDo = 0;
-my (%usedInodes, %filesFromMD5CheckSumFile, $prevDirToCheck);
+# statistical data per backup:
+my $checkedFiles = 0;
+my $checkedFilesSize = 0; # uses size of data in backup (eg. compressed)
+my $linkedFiles = 0;
+my $linkedFilesSize = 0;  # uses size of data in backup (eg. compressed)
+# sums of statistical data:
+my $checkedFilesAll = 0;
+my $checkedFilesSizeAll = 0;
+my $linkedFilesAll = 0;
+my $linkedFilesSizeAll = 0;
+
+# %usedInodes
+## if inode was checked, the inode is used as key, value set to 1
+## if md5sum check of file has different value that stored in .md5CheckSums,
+## inode is marked as 'corrupt' and deleted from that table (so all affected
+## files are reported)
+# %filesFromMD5CheckSumFile
+## key = relative filename
+## value pre-set to 1, then changed to 2 if file is not a blocked file
+## sub checkAllFiles checks, if all files in the backup are in this hash
+# %usedBlockInodes
+## stores inodes already used in blocks
+my (%usedInodes, %filesFromMD5CheckSumFile, $prevDirToCheck,
+    %usedBlockInodes);
+
 while (defined($rcsf) or $jobToDo > 0 or $parForkToDo > 0)
 {
+#print "--o--0--jobToDo=$jobToDo-parForkToDo=$parForkToDo-\n";
     ############################################################
     my $old = $parFork->checkOne();
     if ($old)
     {
 	my ($tmpN, $fn) = @{$old->get('-what' => 'info')};
+#print "--o--1-$fn-\n";
 	local *IN;
-	unless (open(IN, "< $tmpN"))
+	unless (&::waitForFile($tmpN) or
+		open(IN, "< $tmpN"))
 	{
 	    $prLog->print('-kind' => 'E',
-			  '-str' => ["cannot temporary information file " .
+			  '-str' => ["cannot open temporary information file " .
 				     "<$tmpN> of <$fn>"]);
 	    next;
 	}
+#print "--o--2-\n";
 	my $l;
 	while ($l = <IN>)
 	{
 	    chop $l;
+#print "--o--3--$l\n";
 	    my ($what, @l) = split(/\s/, $l, 2);
 	    if ($what eq 'corrupt')
 	    {
@@ -341,6 +477,36 @@ while (defined($rcsf) or $jobToDo > 0 or $parForkToDo > 0)
 			      '-str' =>
 			      ["md5 sum mismatch for <$fn>"]);
 	    }
+	    elsif ($what eq 'errors')
+	    {
+		$prLog->addEncounter('-kind' => 'E',
+				     '-add' => $l[0]);
+	    }
+	    elsif ($what eq 'checkedFiles')
+	    {
+		$checkedFiles += $l[0];
+	    }
+	    elsif ($what eq 'checkedFilesSize')
+	    {
+		$checkedFilesSize += $l[0];
+	    }
+	    elsif ($what eq 'linkedFiles')
+	    {
+		$linkedFiles += $l[0];
+	    }
+	    elsif ($what eq 'linkedFilesSize')
+	    {
+		$linkedFilesSize += $l[0];
+	    }
+	    elsif ($what eq 'calcedInodes')
+	    {
+		while ($l = <IN>)
+		{
+		    chop $l;
+		    $usedBlockInodes{$l} = 1;
+		}
+		last;
+	    }
 	    else
 	    {
 		$prLog->print('-kind' => 'E',
@@ -349,73 +515,100 @@ while (defined($rcsf) or $jobToDo > 0 or $parForkToDo > 0)
 			       "<$tmpN> of $fn"]);
 	    }
 	}
+
+	close(IN);
 	unlink $tmpN;
     }
+#print "--o--4-\n";
 
     ############################################################
     $jobToDo = @dirsToCheck;
     if (($rcsf or $jobToDo > 0) and $parFork->getNoFreeEntries() > 0)
     {
+#print "----0----open $dirToCheck/$checkSumFile\n";
+#print "---jobToDo = $jobToDo, freeEntries=", $parFork->getNoFreeEntries(), ", usedEntries=", $parFork->getNoUsedEntries(), "\n";
+
 	unless ($rcsf)
 	{
+#print "---0.05---\n";
+	    # Wait until all files of the previous actual backup
+	    # are calculated. Do this so 
+	    if ($parFork->getNoUsedEntries() != 0)
+	    {
+		$tinySched->wait();
+		next;
+	    }
+	    # ok, all files of old backup are finished,
+	    # now begin with the next one
+	    if ($verbose)
+	    {
+		&printStat($prLog, '', $checkedFiles, $checkedFilesSize,
+			   $linkedFiles, $linkedFilesSize)
+		    if $checkedFilesSize + $linkedFilesSize > 0;
+		        # avoid first printout before any checks
+	    }
+	    $checkedFilesAll += $checkedFiles;
+	    $checkedFilesSizeAll += $checkedFilesSize;
+	    $linkedFilesAll += $linkedFiles;
+	    $linkedFilesSizeAll += $linkedFilesSize;
+
+	    $checkedFiles = 0;
+	    $checkedFilesSize = 0;
+	    $linkedFiles = 0;
+	    $linkedFilesSize = 0;
+
+#print "---0.1---\n";
 	    $prevDirToCheck = $dirToCheck;
 	    $dirToCheck = shift @dirsToCheck;
 	    last unless $dirToCheck;
 
-	    unless (-r "$dirToCheck/$checkSumFile" or
-		    -r "$dirToCheck/$checkSumFile.bz2")
-	    {
-		$prLog->print('-kind' => 'E',
-			      '-str' => ["no readable <$checkSumFile> in " .
-					 "<$dirToCheck> ... skipping"]);
-		next;
-	    }
-	    if (-f "$dirToCheck/$checkSumFile.notFinished")
-	    {
-		$prLog->print('-kind' => 'E',
-			      '-str' => ["backup <$dirToCheck> not finished" .
-					 " ... skipping"]);
-		next;
-	    }
+#print "---0.2---\n";
 
-#	    my $fm;
-#	    foreach $fm (keys %filesFromMD5CheckSumFile)
-#	    {
-#		print "###$prevDirToCheck##$fm###\n";
-#	    }
 	    &checkAllFiles($prevDirToCheck, \%filesFromMD5CheckSumFile,
 			   $prLog)
 		if %filesFromMD5CheckSumFile;
 	    %filesFromMD5CheckSumFile = ();
 
-	    $rcsf =
-		readCheckSumFile->new('-checkSumFile' =>
-				      "$dirToCheck/$checkSumFile",
-				      '-prLog' => $prLog);
-	    $meta = $rcsf->getMetaValField();
-	    $postfix = ($$meta{'postfix'})->[0];    # postfix for compression
-	    my $writeExcludeLog = ($$meta{'writeExcludeLog'})->[0];
-	    my $logInBackupDir = ($$meta{'logInBackupDir'})->[0];
+	    $rcsf = readCheckSumFile->new('-checkSumFile' =>
+					  "$dirToCheck/$checkSumFile",
+					  '-prLog' => $prLog);
+	    $postfix = $rcsf->getInfoWithPar('postfix');
+	    my $writeExcludeLog = $rcsf->getInfoWithPar('writeExcludeLog');
+	    my $logInBackupDir = $rcsf->getInfoWithPar('logInBackupDir');
 	    my $compressLogInBackupDir =
-		($$meta{'compressLogInBackupDir'})->[0];
-	    ($uncompr, @uncomprPar) = @{$$meta{'uncompress'}};
+		$rcsf->getInfoWithPar('compressLogInBackupDir');
+	    my $logInBackupDirFileName =
+		$rcsf->getInfoWithPar('logInBackupDirFileName');
+	    $logInBackupDirFileName .= '.bz2'
+		if $compressLogInBackupDir eq 'yes';
+	     ($uncompr, @uncomprPar) = @{$rcsf->getInfoWithPar('uncompress')};
+
 	    $filesFromMD5CheckSumFile{'.md5BlockCheckSums.bz2'} = 1;
 	    $filesFromMD5CheckSumFile{'.md5CheckSums.bz2'} = 1;
 	    $filesFromMD5CheckSumFile{'.md5CheckSums'} = 1;
 	    $filesFromMD5CheckSumFile{'.md5CheckSums.info'} = 1;
 	    $filesFromMD5CheckSumFile{'.storeBackupLinks'} = 1;
-	    $filesFromMD5CheckSumFile{'.storeBackup.log'} = 1
-		if $logInBackupDir eq 'yes';
-	    $filesFromMD5CheckSumFile{'.storeBackup.log.bz2'} = 1
-		if $logInBackupDir eq 'yes' and
-		$compressLogInBackupDir eq 'yes';
 	    $filesFromMD5CheckSumFile{'.storeBackup.notSaved.bz2'} = 1
-		if $logInBackupDir eq 'yes';
+		if $writeExcludeLog eq 'yes';
+	    if ($logInBackupDir eq 'yes')
+	    {
+		if ($logInBackupDirFileName)
+		{
+		    $filesFromMD5CheckSumFile{$logInBackupDirFileName} = 1;
+		}
+		else
+		{
+		    $filesFromMD5CheckSumFile{'.storeBackup.log'} = 1;
+		    $filesFromMD5CheckSumFile{'.storeBackup.notSaved.bz2'} = 1;
 
+		    $filesFromMD5CheckSumFile{'.storeBackup.log.bz2'} = 1
+			if $compressLogInBackupDir eq 'yes';
+		}
+	    }
 
 	    $prLog->print('-kind' => 'I',
-			  '-str' => ["checking <$dirToCheck> ..."])
-		if $verbose;
+			  '-str' => ["-- checking <$dirToCheck> ..."]);
+#		if $verbose;
 	}
 	my ($md5sum, $compr, $devInode, $inodeBackup, $ctime, $mtime, $atime,
 	    $size, $uid, $gid, $mode, $f);
@@ -424,15 +617,23 @@ while (defined($rcsf) or $jobToDo > 0 or $parForkToDo > 0)
 	{
 	    $f .= $postfix if $compr eq 'c';
 	    $filesFromMD5CheckSumFile{$f} = 1;
+	    if ($devInode =~ /\ADEVICE/)   # store path to saved device
+	    {
+		foreach my $p (&getRelPaths($f))
+		{
+		    $filesFromMD5CheckSumFile{$p} = 1;
+		}
+	    }
 #print "new file <$f>\n";
+#print "    $dirToCheck/$checkSumFile\n";
 	    my $filename = "$dirToCheck/$f";
 	    if (length($md5sum) == 32)
 	    {
-#print "-1-\n";
+#print "-1-$compr-\n";
 		if ($compr ne 'b')
 		{
-		    $filesFromMD5CheckSumFile{$f} = 2; # blocked file
-		    my $inode = (stat($filename))[1];
+		    $filesFromMD5CheckSumFile{$f} = 2; # not a blocked file
+		    my ($inode, $sizeBackup) = (stat($filename))[1,7];
 #print "-2- inode = $inode, $f\n";
 		    if ($inode)
 		    {
@@ -440,11 +641,15 @@ while (defined($rcsf) or $jobToDo > 0 or $parForkToDo > 0)
 			if (exists $usedInodes{$inode})
 			{
 #print "-3-\n";
+			    ++$linkedFiles;
+			    $linkedFilesSize += $sizeBackup;
 			    next;
 			}
 			$usedInodes{$inode} = 1;
 		    }
 		}
+#print "-3.5-filesFromMD5CheckSumFile\{$f\}=", $filesFromMD5CheckSumFile{$f}, "-\n";
+#print "\tdevInode=<$devInode>\n";
 		unless (-e $filename)
 		{
 		    $prLog->print('-kind' => 'E',
@@ -468,13 +673,14 @@ while (defined($rcsf) or $jobToDo > 0 or $parForkToDo > 0)
 				      '-funcPar' =>
 				      [$dirToCheck, $filename, $md5sum, $compr,
 				       $postfix, $uncompr, \@uncomprPar,
+				       \%usedBlockInodes,
 				       10*1024**2, $tmpName, $prLog],
 				      '-info' => [$tmpName, $filename]);
 	    }
 	    elsif ($md5sum eq 'dir')
 	    {
 		$prLog->print('-kind' => 'E',
-			      '-str' => ["directory <$filename is missing>"])
+			      '-str' => ["directory <$filename> is missing"])
 		    unless -e $filename;
 		$prLog->print('-kind' => 'E',
 			      '-str' => ["<$filename> is not a directory!"])
@@ -508,7 +714,7 @@ while (defined($rcsf) or $jobToDo > 0 or $parForkToDo > 0)
 	    elsif ($md5sum eq 'socket')
 	    {
 		$prLog->print('-kind' => 'E',
-			      '-str' => ["socket <$filename is missing>"])
+			      '-str' => ["socket <$filename> is missing"])
 		    unless -e $filename;
 		$prLog->print('-kind' => 'E',
 			      '-str' => ["<$filename> is not a socket!"])
@@ -517,7 +723,7 @@ while (defined($rcsf) or $jobToDo > 0 or $parForkToDo > 0)
 	    elsif ($md5sum eq 'blockdev')
 	    {
 		$prLog->print('-kind' => 'E',
-			      '-str' => ["block device <$filename is missing>"])
+			      '-str' => ["block device <$filename> is missing"])
 		    unless -e $filename;
 		$prLog->print('-kind' => 'E',
 			      '-str' => ["<$filename> is not a block device!"])
@@ -526,50 +732,60 @@ while (defined($rcsf) or $jobToDo > 0 or $parForkToDo > 0)
 	    elsif ($md5sum eq 'chardev')
 	    {
 		$prLog->print('-kind' => 'E',
-			      '-str' => ["char device <$filename is missing>"])
+			      '-str' => ["char device <$filename> is missing"])
 		    unless -e $filename;
 		$prLog->print('-kind' => 'E',
 			      '-str' => ["<$filename> is not a char device!"])
 		    unless -c $filename;
 	    }
 
+#print "-10-$f\n";
 	    $tinySched->reset();
 	}
 	else
 	{
-#print "1 rcsf = undef\n";
+#print "-11- rcsf = undef\n";
 	    $rcsf = undef;
 	}
+#print "-10-\n";
     }
 
     ############################################################
     $tinySched->wait();
 
     $parForkToDo = $parFork->getNoUsedEntries();
-#print "2 rcsf = $rcsf, parForkToDo = $parForkToDo\n";
-}
-#print "--------------ENDE---------\n";
-#	    my $fm;
-#	    foreach $fm (keys %filesFromMD5CheckSumFile)
-#	    {
-#		print "###$dirToCheck##$fm###\n";
-#	    }
+#print "2 parForkToDo = $parForkToDo\n";
+}     # end of global while loop over all jobs
+
 &checkAllFiles($dirToCheck, \%filesFromMD5CheckSumFile,
 	       $prLog)
     if %filesFromMD5CheckSumFile;
 
 
+if ($verbose)
+{
+    &printStat($prLog, '', $checkedFiles, $checkedFilesSize,
+	       $linkedFiles, $linkedFilesSize);
+
+    $checkedFilesAll += $checkedFiles;
+    $checkedFilesSizeAll += $checkedFilesSize;
+    $linkedFilesAll += $linkedFiles;
+    $linkedFilesSizeAll += $linkedFilesSize;
+    &printStat($prLog, 'overall', $checkedFilesAll, $checkedFilesSizeAll,
+	       $linkedFilesAll, $linkedFilesSizeAll);
+}
+
 my $enc = $prLog->encountered('-kind' => 'W');
 my $S = $enc > 1 ? 'S' : '';
 if ($enc)
 {
     $prLog->print('-kind' => 'W',
-		  '-str' => ["-- $enc WARNING$S OCCURED DURING THE CHECK! --"])
+		  '-str' => ["-- $enc WARNING$S OCCURRED DURING THE CHECK! --"])
 }
 else
 {
     $prLog->print('-kind' => 'I',
-		  '-str' => ["-- no WARNINGS OCCURED DURING THE CHECK! --"]);
+		  '-str' => ["-- no WARNINGS OCCURRED DURING THE CHECK! --"]);
 }
 
 $enc = $prLog->encountered('-kind' => 'E');
@@ -577,12 +793,12 @@ $S = $enc > 1 ? 'S' : '';
 if ($enc)
 {
     $prLog->print('-kind' => 'E',
-		  '-str' => ["-- $enc ERROR$S OCCURED DURING THE CHECK! --"]);
+		  '-str' => ["-- $enc ERROR$S OCCURRED DURING THE CHECK! --"]);
 }
 else
 {
     $prLog->print('-kind' => 'I',
-		  '-str' => ["-- no ERRORS OCCURED DURING THE CHECK! --"]);
+		  '-str' => ["-- no ERRORS OCCURRED DURING THE CHECK! --"]);
 }
 
 
@@ -592,23 +808,38 @@ if ($prLog->encountered('-kind' => "E"))
 }
 else
 {
+    $prLog->print('-kind' => 'Z',
+		  '-str' => ["checking backups in <" .
+			     ::absolutePath($backupDir) . ">"]);
     exit 0;
 }
 
 
 ############################################################
+# checks calculated md5 sum against stored one(s)
+# this function is called for all files (blocked and non-blocked
 sub checkMD5
 {
     my ($dirToCheck, $f, $md5sum, $compr, $postfix, $uncompr, $uncomprPar,
-	$blockSize, $tmpName, $prLog) = @_;
+	$usedBlockInodes, $blockSize, $tmpName, $prLog) = @_;
+
+    my (%inode2md5);   # store calculated md5 sum of new inodes
+
+    # statistical data per checkMD5
+    my $checkedFiles = 0;
+    my $checkedFilesSize = 0;
+    my $linkedFiles = 0;
+    my $linkedFilesSize = 0;
 
     local *OUT;
     open(OUT, "> $tmpName") or
 	$prLog->print('-kind' => 'E',
 		      '-str' => ["cannot open <$tmpName>"],
+		      '-add' => [__FILE__, __LINE__],
 		      '-exit' => 1);
 
-# print "-------------$f----------, $md5sum\n";
+#print "checkMD5 -------------$f----------, $md5sum, ", length($md5sum), ", compr=$compr\n";
+    my $nrErrors = 0;
     if (length($md5sum) == 32)
     {
 	if ($compr eq 'u' or $compr eq 'c')
@@ -620,6 +851,8 @@ sub checkMD5
 	    {
 		$prLog->print('-kind' => 'E',
 			      '-str' => ["file <$f> is missing"]);
+		++$nrErrors;
+		print OUT "errors $nrErrors\n";
 		return 1;
 	    }
 	    if ($compr eq 'u')
@@ -627,7 +860,10 @@ sub checkMD5
 		unless (sysopen(FILE, $f, O_RDONLY))
 		{
 		    $prLog->print('-kind' => 'E',
-				  '-str' => ["cannot open <$f>"]);
+				  '-str' => ["cannot open <$f>"],
+				  '-add' => [__FILE__, __LINE__]);
+		    ++$nrErrors;
+		    print OUT "errors $nrErrors\n";
 		    return 1;
 		}
 	    }
@@ -640,6 +876,10 @@ sub checkMD5
 				      '-outRandom' => '/tmp/stbuPipeFrom10-',
 				      '-prLog' => $prLog);
 	    }
+
+	    my ($inode, $size) = (stat($f))[1,7];
+	    ++$checkedFiles;
+	    $checkedFilesSize += $size;
 	    my $buffer;
 	    while ($fileIn ? $fileIn->sysread(\$buffer, $blockSize) :
 		   sysread(FILE, $buffer, $blockSize))
@@ -649,13 +889,11 @@ sub checkMD5
 
 	    if ($md5sum ne $md5All->hexdigest())
 	    {
-		my $inode = (stat($f))[1];
 		print OUT "corrupt $inode $f\n";
-#		print "md5 sum does not match at <$f>\n";
 	    }
 	    else
 	    {
-#		print "checked <$f>\n";
+		# ready
 	    }
 	    if ($fileIn)
 	    {
@@ -666,18 +904,22 @@ sub checkMD5
 	    {
 		close(FILE);
 	    }
-	}
+	}                       # if ($compr eq 'u' or $compr eq 'c')
 	elsif ($compr eq 'b')
 	{
+#print "start checking blocked file $f\n";
 	    # read all files in directory
 	    local *DIR;
 	    unless (opendir(DIR, $f))
 	    {
 		$prLog->print('-kind' => 'E',
-			      '-str' => ["cannot open <$f>"]);
+			      '-str' => ["cannot open <$f>"],
+			      '-add' => [__FILE__, __LINE__]);
+		++$nrErrors;
+		print OUT "errors $nrErrors\n";
 		return 1;
 	    }
-	    my ($entry, @entries, %inode2md5);
+	    my ($entry, @entries);
 	    while ($entry = readdir DIR)  # one entry per inode
 	    {
 		next unless $entry =~ /\A\d/;
@@ -693,38 +935,56 @@ sub checkMD5
 				  '-prLog' => $prLog);
 
 	    my $l;
-#	    while ($l = <FILE>)
 	    while ($l = $fileIn->read())
 	    {
 		chomp $l;
 		my ($l_md5, $l_compr, $l_f, $n);
 		$n = ($l_md5, $l_compr, $l_f) = split(/\s/, $l, 3);
-		$prLog->print('-kind' => 'E',
-			      '-str' =>
-			      ["strange line in <$f/.md5BlockCheckSums.bz2> " .
-			       "in line $.:", "\t<$l>"],
-			      '-exit' => 1)
-		    if ($n != 3);
+		if ($n != 3)
+		{
+		    ++$nrErrors;
+		    print OUT "errors $nrErrors\n";
+		    $prLog->print('-kind' => 'E',
+				  '-str' =>
+				  ["strange line in <$f/.md5BlockCheckSums.bz2> " .
+				   "in line " . $fileIn->get('-what' => 'lineNr') .
+				   ":", "\t<$l>"],
+				  '-exit' => 1)
+		}
 		if (-e "$dirToCheck/$l_f")
 		{
 		    my $inode = (stat("$dirToCheck/$l_f"))[1];
 		    $inode2md5{$inode} = $l_md5;
-#		    print "$l_f: $inode -> $l_md5\n";
+#print "$l_f: $inode -> $l_md5\n";
 		}
 		else
 		{
 		    $prLog->print('-kind' => 'E',
-				  '-str' => ["<$l_f> is missing"]);
+				  '-str' => ["file <$l_f> is missing"]);
 		}
 	    }
-#	    close(FILE);
 	    $fileIn->close();
 	    $fileIn = undef;
 
 	    my $md5All = Digest::MD5->new();
-	    foreach $entry (sort @entries)
+	    foreach $entry (sort @entries)  # loop over all files in backup
 	    {
-		my $inode = (stat("$f/$entry"))[1];
+		my ($inode, $size) = (stat("$f/$entry"))[1,7];
+
+		my $calcMD5 = 0;
+		if (exists $$usedBlockInodes{$inode})
+		{
+#print "inode already calculated: $inode\n";
+		    ++$linkedFiles;
+		    $linkedFilesSize += $size;
+		}
+		else
+		{
+		    ++$checkedFiles;
+		    $checkedFilesSize += $size;
+		    $calcMD5 = 1;
+		}
+		$$usedBlockInodes{$inode} = $inode;
 
 		local *FROM;
 		my $fileIn = undef;
@@ -743,17 +1003,18 @@ sub checkMD5
 		    {
 			$prLog->print('-kind' => 'E',
 				      '-str' => ["cannot read <$f/$entry>"]);
+			++$nrErrors;
+			print OUT "errors $nrErrors\n";
 			return 1;
 		    }
 		}
 		my $buffer;
-		my $md5Block = Digest::MD5->new();
-		my $size;
-		while ($size = $fileIn ? $fileIn->sysread(\$buffer, $blockSize) :
+		my $md5Block = Digest::MD5->new() if $calcMD5;
+		while ($fileIn ? $size = $fileIn->sysread(\$buffer, $blockSize) :
 		       sysread(FROM, $buffer, $blockSize))
 		{
 		    $md5All->add($buffer);
-		    $md5Block->add($buffer);
+		    $md5Block->add($buffer) if $calcMD5;
 		}
 		if ($fileIn)
 		{
@@ -765,12 +1026,23 @@ sub checkMD5
 		    close(FILE);
 		}
 
-		my $digest = $md5Block->hexdigest();
-#		print "$f/$entry:\n";
-#		print "\t$digest = digest\n";
-#		print "\t", $inode2md5{$inode}, " = inode ($inode)\n";
-		if ($digest ne $inode2md5{$inode})
+		my $digest = $md5Block->hexdigest() if $calcMD5;
+#print "$f/$entry:\n";
+#print "\t$digest = digest\n";
+#print "\t", $inode2md5{$inode}, " = inode ($inode)\ if $calcMD5;n";
+		if (not exists $inode2md5{$inode})
 		{
+		    ++$nrErrors;
+		    print OUT "errors $nrErrors\n";
+		    $prLog->print('-kind' => 'E',
+				  '-str' =>
+				  ["<$f/$entry> is missing in " .
+				   "<$f/.md5BlockCheckSums.bz2>"]);
+		}
+		elsif ($calcMD5 and $digest ne $inode2md5{$inode})
+		{
+		    ++$nrErrors;
+		    print OUT "errors $nrErrors\n";
 		    $prLog->print('-kind' => 'E',
 				  '-str' =>
 				  ["calculated md5 sum of <$f/$entry> is " .
@@ -786,11 +1058,26 @@ sub checkMD5
 	    }
 	    else
 	    {
-#		print "checked <$f>\n";
+#print "end checking blocked file $f\n";
+		# ready
 	    }
+#print "checked <$f>\n";
 	}
     }
 
+    print OUT "errors $nrErrors\n";
+    print OUT "checkedFiles $checkedFiles\n";
+    print OUT "checkedFilesSize $checkedFilesSize\n";
+    print OUT "linkedFiles $linkedFiles\n";
+    print OUT "linkedFilesSize $linkedFilesSize\n";
+
+    print OUT "calcedInodes\n";
+    my $i;
+    foreach $i (keys %inode2md5)
+    {
+	print OUT "$i\n";
+    }
+
     close(OUT);
     return 0;
 }
@@ -798,10 +1085,12 @@ sub checkMD5
 
 ############################################################
 # check if all files in $dir are in the hash
+# and if files in $dir are missing in the hash
 sub checkAllFiles
 {
     my ($dir, $relFiles, $prLog) = @_;
 
+#print "-1- keys relFiles=\n\t", join("\n\t", sort keys %$relFiles), "\n";
     &_checkAllFiles(length($dir)+1, $dir, $relFiles, $prLog);
 }
 
@@ -811,18 +1100,19 @@ sub _checkAllFiles
 {
     my ($length, $dir, $relFiles, $prLog) = @_;
 
-#print "_checkAllFiles: $length, $dir\n";
+#print "-2- _checkAllFiles: $length, $dir\n";
 
     my $rel = undef;
     if (length($dir) > $length)
     {
 	$rel = substr($dir, $length);
+#print "\t-3- set1 rel <$rel>\n";
     }
     if ($rel)
     {
-#	print "\tcheck-> <$rel>\n";
+#print "\t-4- check1-> <$rel>\n";
 	$prLog->print('-kind' => 'E',
-		      '-str' => ["<$rel> is not listed in .md5CheckSum"])
+		      '-str' => ["<$rel> is not listed in .md5CheckSum (1)"])
 	    unless exists $$relFiles{$rel};
     }
 
@@ -838,21 +1128,70 @@ sub _checkAllFiles
     {
 	next if ($e eq '.' or $e eq '..');
 	my $de = "$dir/$e";
-	if (-d $de and not -l $de)   # is a directory
-	{
-	    if ($$relFiles{$rel} == 1)  # not a blocked file
-	    {
-		&_checkAllFiles($length, $de, $relFiles, $prLog);
-	    }
-	    next;
-	}
+#print "\t-5- de <$de>\n";
+
+# don't care about blocked files, they are already check
+# in sub checkMD5
+
 	$rel = substr($de, $length);
-#	print "\tcheck-> <$rel>\n";
+#print "\t-10- set2 rel <$rel>\n";
 	$prLog->print('-kind' => 'E',
-		      '-str' => ["<$rel> is not listed in .md5CheckSum"])
+		      '-str' => ["<$rel> is not listed in .md5CheckSum (2)"])
 	    unless exists $$relFiles{$rel};
     }
     closedir(DIR) or
 	$prLog->print('-kind' => 'E',
 		      '-str' => ["cannot closedir <$dir>"]);
 }
+
+
+##################################################
+# package printLogMultiple needs this function
+sub cleanup
+{
+    my $signame = shift;
+    my $exit = (shift() || 1);
+
+    exit $exit;
+}
+
+
+##################################################
+# print statistical data
+sub printStat
+{
+    my ($prLog, $text, $checkedFiles, $checkedFilesSize,
+	$linkedFiles, $linkedFilesSize) = (@_);
+
+    my $checkP = 0;
+
+    $checkP = int($checkedFilesSize * 10000 /
+		  ($checkedFilesSize + $linkedFilesSize) +.5) / 100
+		  if ($checkedFilesSize + $linkedFilesSize) > 0;
+
+    $prLog->print('-kind' => 'S',
+		  '-str' => ["$text checked $checkedFiles files (" .
+			     (&::humanReadable($checkedFilesSize))[0] .
+			     ") (" . $checkP . "%)",
+			     "$text linked files were $linkedFiles (" . 
+			     (&::humanReadable($linkedFilesSize))[0] . ")"]);
+}
+
+##################################################
+# get all directories to a given relative path, eg.
+# <a/b//c> -> <a> <a/b> <a/b/c>
+sub getRelPaths
+{
+    my $path = shift;
+
+    $path =~ s#//#/#g;
+ 
+    my (@parts) = split('/', $path);
+    my (@res);
+    for (my $n = 0 ; $n < @parts ; $n++)
+    {
+	push @res, join('/', @parts[0..$n]);
+    }
+
+    return @res;
+}
