@@ -1,7 +1,7 @@
 #!/usr/bin/env perl
 
 #
-#   Copyright (C) Dr. Heinz-Josef Claes (2012-2020)
+#   Copyright (C) Dr. Heinz-Josef Claes (2012)
 #                 hjclaes@web.de
 #
 #   This program is free software: you can redistribute it and/or modify
@@ -95,6 +95,7 @@ require 'checkObjPar.pl';
 require 'prLog.pl';
 require 'version.pl';
 require 'fileDir.pl';
+require 'forkProc.pl';
 require 'storeBackupLib.pl';
 
 my $checkSumFile = '.md5CheckSums';
@@ -124,9 +125,8 @@ compared to the backup, it:
 =head1 SYNOPSIS
 
     storeBackupCheckSource.pl -s sourceDir -b singleBackupDir [-v]
-	      [-w filePrefix]
 	      [--logFile
-	       [--plusLogStdout] [--suppressTime] [-m maxFilelen]
+	       [--suppressTime] [-m maxFilelen]
 	       [[-n noOfOldFiles] | [--saveLogs]]
 
 =head1 OPTIONS
@@ -147,25 +147,10 @@ compared to the backup, it:
 
     also print positive messages (file is identical in source and backup)
 
-=item B<--wrongFileTables>, B<-w>
-
-    write filenames with detected faults in regular files for
-    later bug fixing (not automated)
-    parameter to this option is a file prefix
-    eg. if the file prefix is '/tmp/bugsS-', the following files are
-    generated:
-    /tmp/bugsS-files.missing.txt
-    /tmp/bugsS-md5sums.wrong.txt
-
 =item B<--logFile>, B<-l>
 
     logFile, Default: stdout
 
-=item B<--plusLogStdout>
-
-    if you specify a log file with --logFile you can
-    additionally print the output to STDOUT with this flag
-
 =item B<--suppressTime>
 
     suppress output of time in logfile
@@ -181,7 +166,7 @@ compared to the backup, it:
 =item B<--saveLogs>
 
     save log files with date and time instead of deleting the
-    old (with [-noOfOldFiles])
+    old (with [-noOldFiles])
 
 =item B<--compressWith>
 
@@ -192,14 +177,16 @@ compared to the backup, it:
 
 =head1 COPYRIGHT
 
-Copyright (c) 2012-2020 by Heinz-Josef Claes (see README).
+Copyright (c) 2012 by Heinz-Josef Claes (see README).
 Published under the GNU General Public License v3 or any later version
 
 =cut
 
-my $Help = &::getPod2Text($0);
+my $Help = join('', grep(!/^\s*$/, `pod2text $0`));
+$Help = "cannot find pod2text, see documentation for details\n"
+    unless $Help;
 
-&printVersion(\@ARGV, '-V', '--version');
+&printVersion(\@ARGV, '-V');
 
 my $CheckPar =
     CheckParam->new('-allowLists' => 'no',
@@ -216,18 +203,11 @@ my $CheckPar =
 				Option->new('-name' => 'verbose',
 					    '-cl_option' => '-v',
 					    '-cl_alias' => '--verbose'),
-				Option->new('-name' => 'wrongFileTables',
-					    '-cl_option' => '-w',
-					    '-cl_alias' => '--wrongFileTables',
-					    '-param' => 'yes'),
 				Option->new('-name' => 'logFile',
 					    '-cl_option' => '-l',
 					    '-cl_alias' => '--logFile',
 					    '-param' => 'yes',
 					    '-only_if' => 'not [interactive]'),
-				Option->new('-name' => 'plusLogStdout',
-					    '-cl_option' => '--plusLogStdout',
-					    '-only_if' => '[logFile]'),
 				Option->new('-name' => 'suppressTime',
 					    '-cl_option' => '--suppressTime'),
 				Option->new('-name' => 'maxFilelen',
@@ -250,13 +230,7 @@ my $CheckPar =
 					    '-cl_option' => '--compressWith',
 					    '-quoteEval' => 'yes',
                                             '-default' => 'bzip2',
-                                            '-only_if' =>'[logFile]'),
-# hidden options
-# used by storeBackupMount.pl
-				Option->new('-name' => 'writeToNamedPipe',
-					    '-cl_option' => '--writeToNamedPipe',
-					    '-param' => 'yes',
-					    '-hidden' => 'yes')
+                                            '-only_if' =>'[logFile]')
 				]);
 
 $CheckPar->check('-argv' => \@ARGV,
@@ -264,12 +238,11 @@ $CheckPar->check('-argv' => \@ARGV,
                  );
 
 
+
 my $singleBackupDir = $CheckPar->getOptWithPar('singleBackupDir');
 my $sourceDir = $CheckPar->getOptWithPar('sourceDir');
 my $verbose = $CheckPar->getOptWithoutPar('verbose');
-my $wrongFileTables = $CheckPar->getOptWithPar('wrongFileTables');
 my $logFile = $CheckPar->getOptWithPar('logFile');
-my $plusLogStdout = $CheckPar->getOptWithoutPar('plusLogStdout');
 my $withTime = not $CheckPar->getOptWithoutPar('suppressTime');
 $withTime = $withTime ? 'yes' : 'no';
 my $maxFilelen = $CheckPar->getOptWithPar('maxFilelen');
@@ -277,8 +250,6 @@ my $noOfOldFiles = $CheckPar->getOptWithPar('noOfOldFiles');
 my $saveLogs = $CheckPar->getOptWithPar('saveLogs');
 $saveLogs = $saveLogs ? 'yes' : 'no';
 my $compressWith = $CheckPar->getOptWithPar('compressWith');
-# hidden options
-my $writeToNamedPipe = $CheckPar->getOptWithPar('writeToNamedPipe');
 
 
 my (@par) = ();
@@ -298,29 +269,13 @@ my ($prLogKind) = ['A:BEGIN',
 		   'V:VERSION',
 		   'W:WARNING',
 		   'E:ERROR'];
-my $printLog = printLog->new('-kind' => $prLogKind,
-			     @par,
-			     '-withTime' => $withTime,
-			     '-maxFilelen' => $maxFilelen,
-			     '-noOfOldFiles' => $noOfOldFiles,
-			     '-saveLogs' => $saveLogs,
-			     '-compressWith' => $compressWith);
-
-my $prLog = printLogMultiple->new('-prLogs' => [$printLog]);
-
-if ($plusLogStdout)
-{
-    my $p = printLog->new('-kind' => $prLogKind,
-			  '-filedescriptor', *STDOUT);
-    $prLog->add('-prLogs' => [$p]);
-}
-if ($writeToNamedPipe)
-{
-    my $np = printLog->new('-kind' => $prLogKind,
-			   '-file' => $writeToNamedPipe,
-			   '-maxFilelen' => 0);
-    $prLog->add('-prLogs' => [$np]);
-}
+my $prLog = printLog->new('-kind' => $prLogKind,
+			  @par,
+			  '-withTime' => $withTime,
+			  '-maxFilelen' => $maxFilelen,
+			  '-noOfOldFiles' => $noOfOldFiles,
+			  '-saveLogs' => $saveLogs,
+			  '-compressWith' => $compressWith);
 
 
 $prLog->print('-kind' => 'E',
@@ -335,13 +290,9 @@ $prLog->print('-kind' => 'E',
     if -e "$singleBackupDir/.storeBackupLinks/linkFile.bz2";
 
 
-(@main::cleanup) = ($prLog, undef);
-$SIG{INT} = \&cleanup;
-$SIG{TERM} = \&cleanup;
-
 
 $prLog->print('-kind' => 'A',
-	      '-str' => ["comparing <$singleBackupDir> with <$sourceDir>"]);
+	      '-str' => ["comparing <$singleBackupDir> to <$sourceDir>"]);
 $prLog->print('-kind' => 'V',
 	      '-str' => ["storeBackupCheckSource.pl, $main::STOREBACKUPVERSION"]);
 
@@ -350,12 +301,6 @@ my $rcsf = readCheckSumFile->new('-checkSumFile' =>
 				 "$singleBackupDir/$checkSumFile",
 				 '-prLog' => $prLog);
 
-$main::wft =
-    writeBugsToFiles->new('-filePrefix' => $wrongFileTables,
-			  '-backupDir' => &::absolutePath($sourceDir),
-			  '-prLog' => $prLog,
-			  '-md5Missing' => 0);
-
 my ($md5sum, $compr, $devInode, $inodeBackup, $ctime, $mtime, $atime,
     $size, $uid, $gid, $mode, $filename);
 while ((($md5sum, $compr, $devInode, $inodeBackup, $ctime, $mtime, $atime,
@@ -379,8 +324,6 @@ while ((($md5sum, $compr, $devInode, $inodeBackup, $ctime, $mtime, $atime,
 	    {
 		$prLog->print('-kind' => 'E',
 			      '-str' => ["file <$f> exists but is unreadable"]);
-		$main::wft->print(&::absolutePath($f), 'fileMissing');
-
 		next;
 	    }
 	    my ($actMode, $actUid, $actGid, $actCtime, $actMtime,
@@ -429,7 +372,6 @@ while ((($md5sum, $compr, $devInode, $inodeBackup, $ctime, $mtime, $atime,
 				  ["<$f> has same ctime / mtime / size " .
 				   "as in backup but different md5 sums: $actMd5 in " .
 				   "sourceDir ; $md5sum in backup"]);
-		    $main::wft->print(&::absolutePath($f), 'md5Wrong');
 		}
 	    }
 	    else
@@ -501,14 +443,3 @@ else
 }
 
 exit 0;
-
-
-##################################################
-# package printLogMultiple needs this function
-sub cleanup
-{
-    my $signame = shift;
-    my $exit = (shift() || 1);
-
-    exit $exit;
-}
