@@ -1,7 +1,7 @@
 #! /usr/bin/env perl
 
 #
-#   Copyright (C) Dr. Heinz-Josef Claes (2003-2009)
+#   Copyright (C) Dr. Heinz-Josef Claes (2003-2012)
 #                 hjclaes@web.de
 #
 #   This program is free software: you can redistribute it and/or modify
@@ -19,9 +19,6 @@
 #
 
 
-my $VERSION = '$Id: storeBackupDel.pl 356 2009-04-27 08:51:49Z hjc $ ';
-push @VERSION, $VERSION;
-my ($VERSIONpName, $VERSIONsvnID) = $VERSION =~ /Id:\s+(\S+)\s+(\d+)/;
 $main::STOREBACKUPVERSION = undef;
 
 
@@ -154,7 +151,7 @@ storeBackupDel.pl - this program deletes backups created by storeBackup
 =item B<--lockFile>, B<-L>
 
     lock file, if exists, new instances will finish if
-    an old is allready running, default is $lockFile
+    an old is already running, default is $lockFile
 
 =item B<--doNotDelete>
 
@@ -298,7 +295,7 @@ storeBackupDel.pl - this program deletes backups created by storeBackup
 
 =head1 COPYRIGHT
 
-Copyright (c) 2003-2008 by Heinz-Josef Claes (see README).
+Copyright (c) 2003-2012 by Heinz-Josef Claes (see README).
 Published under the GNU General Public License v3 or any later version
 
 =cut
@@ -307,7 +304,7 @@ my $Help = join('', grep(!/^\s*$/, `pod2text $0`));
 $Help = "cannot find pod2text, see documentation for details\n"
     unless $Help;
 
-&printVersions(\@ARGV, '-V');
+&printVersion(\@ARGV, '-V');
 
 my $startDate = dateTools->new();
 
@@ -499,26 +496,37 @@ if ($print)
     exit 0;
 }
 
-my $prLog;
-my (@kind) = ('I:INFO', 'W:WARNING', 'E:ERROR', 'S:STATISTIC',
-	      'D:DEBUG', 'V:VERSION');
+my $prLog1;
+my (@kind) = ('A:BEGIN', 'Z:END','I:INFO', 'W:WARNING', 'E:ERROR',
+	      'S:STATISTIC', 'D:DEBUG', 'V:VERSION');
 
 if ($logFile)
 {
-    $prLog = printLog->new('-kind' => \@kind,
-			   '-file' => $logFile,
-			  '-withTime' => $withTime,
-			  '-maxFilelen' => $maxFilelen,
-			  '-noOfOldFiles' => $noOfOldFiles);
+    $prLog1 = printLog->new('-kind' => \@kind,
+			    '-file' => $logFile,
+			    '-withTime' => $withTime,
+			    '-maxFilelen' => $maxFilelen,
+			    '-noOfOldFiles' => $noOfOldFiles);
 }
 else
 {
-    $prLog = printLog->new('-kind' => \@kind);
+    $prLog1 = printLog->new('-kind' => \@kind);
 }
 
+my $prLog = printLogMultiple->new('-prLogs' => [$prLog1]);
+
+if ($plusLogStdout)
+{
+    my $p = printLog->new('-kind' => \@kind,,
+			  '-filedescriptor', *STDOUT);
+    $prLog->add('-prLogs' => [$p]);
+}
+
+$prLog->print('-kind' => 'A',
+	      '-str' =>
+	      ["starting deletion in <$backupDir>, series <$series>"]);
 $prLog->print('-kind' => 'V',
-	      '-str' => ["$VERSIONpName, $main::STOREBACKUPVERSION, " .
-			 "build $VERSIONsvnID"]);
+	      '-str' => ["storeBackupDel.pl, $main::STOREBACKUPVERSION"]);
 
 $prLog->print('-kind' => 'E',
 	      '-str' => ["backupDir directory <$backupDir> does not exist\n$Help"],
@@ -562,7 +570,7 @@ if ($lockFile)
 	{
 	    $prLog->print('-kind' => 'E',
 			  '-str' => ["cannot start, old instance with pid " .
-				     "<$pid> is allready running"],
+				     "<$pid> is already running"],
 			  '-exit' => 1);
 	}
 	else
@@ -677,4 +685,9 @@ $prLog->print('-kind' => 'I',
 	      '-str' => ["removing lock file <$lockFile>"]);
 unlink $lockFile;
 
+$prLog->print('-kind' => 'Z',
+	      '-str' =>
+	      ["finished deletion in <$backupDir>, series <$series>"]);
+
+
 exit 0;
