@@ -1,7 +1,7 @@
 #! /usr/bin/env perl
 
 #
-#   Copyright (C) Dr. Heinz-Josef Claes (2002-2020)
+#   Copyright (C) Dr. Heinz-Josef Claes (2002-2012)
 #                 hjclaes@web.de
 #   
 #   This program is free software: you can redistribute it and/or modify
@@ -23,8 +23,7 @@ $main::STOREBACKUPVERSION = undef;
 
 
 use strict;
-use Fcntl;
-use Digest::MD5 qw(md5_hex);
+use DB_File;           # Berkeley DB version 1
 
 
 sub libPath
@@ -88,7 +87,6 @@ sub splitFileDir
 my ($req, $prog) = &libPath($0);
 push @INC, "$req";
 
-require 'storeBackupGlob.pl';
 require 'checkParam2.pl';
 require 'checkObjPar.pl';
 require 'prLog.pl';
@@ -101,7 +99,6 @@ require 'storeBackupLib.pl';
 my $md5CheckSumVersion = '1.1';
 my $noRestoreParallel = 12;
 my $checkSumFile = '.md5CheckSums';
-my $exit = 0;
 
 my $tmpdir = '/tmp';              # default value
 $tmpdir = $ENV{'TMPDIR'} if defined $ENV{'TMPDIR'};
@@ -114,7 +111,7 @@ storeBackupRecover.pl - recovers files saved with storeBackup.pl.
 
 	storeBackupRecover.pl -r restore [-b root] -t targetDir [--flat]
 		[-o] [--tmpdir] [--noHardLinks] [-p number] [-v] [-n]
-		[--cpIsGnu] [--noGnuCp] [-s]
+		[--cpIsGnu] [--noGnuCp]
 
 =head1 OPTIONS
 
@@ -170,23 +167,20 @@ storeBackupRecover.pl - recovers files saved with storeBackup.pl.
     installed
     (only relevant for sockets, block and character devices)
 
-=item B<--createSparseFiles>, B<-s>
-
-    creates sparse file from blocked files if full blockes
-    are filled with zeros
-
 =back
 
 =head1 COPYRIGHT
 
-Copyright (c) 2002-2020 by Heinz-Josef Claes (see README).
+Copyright (c) 2002-2012 by Heinz-Josef Claes (see README).
 Published under the GNU General Public License v3 or any later version
 
 =cut
 
-my $Help = &::getPod2Text($0);
+my $Help = join('', grep(!/^\s*$/, `pod2text $0`));
+$Help = "cannot find pod2text, see documentation for details\n"
+    unless $Help;
 
-&printVersion(\@ARGV, '-V', '--version');
+&printVersion(\@ARGV, '-V');
 
 my $CheckPar =
     CheckParam->new('-allowLists' => 'no',
@@ -227,10 +221,7 @@ my $CheckPar =
 					    '-cl_option' => '-n',
 					    '-cl_alias' => '--noRestored'),
 				Option->new('-name' => 'noGnuCp',
-					    '-cl_option' => '--noGnuCp'),
-				Option->new('-name' => 'createSparseFiles',
-					    '-cl_option' => '--createSparseFiles',
-					    '-cl_alias' => '-s')
+					    '-cl_option' => '--noGnuCp')
 				]
 		    );
 
@@ -250,12 +241,10 @@ my $noRestoreParallel = $CheckPar->getOptWithPar('noRestoreParallel');
 my $verbose = $CheckPar->getOptWithoutPar('verbose');
 my $noRestored = $CheckPar->getOptWithoutPar('noRestored');
 my $noGnuCp = $CheckPar->getOptWithoutPar('noGnuCp');
-my $createSparseFiles = $CheckPar->getOptWithoutPar('createSparseFiles');
 
 
 my $prLog = printLog->new('-kind' => ['I:INFO', 'W:WARNING', 'E:ERROR',
-				      'S:STATISTIC', 'D:DEBUG', 'V:VERSION'],
-			  '-tmpdir' => $tmpdir);
+				      'S:STATISTIC', 'D:DEBUG', 'V:VERSION']);
 $prLog->fork($req);
 
 $prLog->print('-kind' => 'E',
@@ -267,15 +256,6 @@ $prLog->print('-kind' => 'V',
 	      '-str' => ["storeBackupRecover.pl, $main::STOREBACKUPVERSION"])
     if $verbose;
 
-eval "use DB_File";
-if ($@)
-{
-    $prLog->print('-kind' => 'I',
-		  '-str' => ["please install DB_File from " .
-			     "CPAN for better performance"])
-	if $verbose;
-}
-
 my $rt = $restoreTree;
 my $restoreTree = &absolutePath($restoreTree);
 $restoreTree = $1 if $restoreTree =~ /(.*)\/$/;  # remove trailing '/'
@@ -366,20 +346,23 @@ unless ($flat)
 
 my $rcsf = readCheckSumFile->new('-checkSumFile' =>
 				 "$backupRoot/$checkSumFile",
-				 '-prLog' => $prLog,
-				 '-tmpdir' => $tmpdir);
+				 '-prLog' => $prLog);
 
 my $fork = parallelFork->new('-maxParallel' => $noRestoreParallel,
 			     '-prLog' => $prLog);
 
+#my $meta = $rcsf->getMetaValField();
+
+#my ($uncompr, @uncomprPar) = @{$$meta{'uncompress'}};
 my ($uncompr, @uncomprPar) = @{$rcsf->getInfoWithPar('uncompress')};
+#my ($cp, @cpPar) = ('cp', '-dPR');
 my ($cp, @cpPar) = ('cp', '-dPR');
+#my $postfix = ($$meta{'postfix'})->[0];
 my $postfix = $rcsf->getInfoWithPar('postfix');
+#my $gnucp = ($$meta{'cpIsGnu'})->[0];
 my $gnucp = $rcsf->getInfoWithPar('cpIsGnu');
 $gnucp = ($gnucp eq 'yes') ? 1 : 0;
 $gnucp = 0 if $noGnuCp;
-my $archiveTypes = $rcsf->getInfoWithPar('archiveTypes');
-my $specialTypeArchiver = $rcsf->getInfoWithPar('specialTypeArchiver');
 
 $main::IOCompressDirect = 0;
 if ($uncompr eq 'bzip2' or $uncompr eq 'bunzip2')
@@ -465,14 +448,6 @@ while ((($md5sum, $compr, $devInode, $inodeBackup, $ctime, $mtime, $atime,
 	{
 	    $targetFile = "$targetDir/$filename";
 	}
-	$targetFile =~ s/\/+/\//g;        # // -> /
-
-	if (not $overwrite and -e $targetFile)
-	{
-	    $prLog->print('-kind' => 'W',
-			  '-str' => ["target $targetFile already exists"]);
-	    next;
-	}
 
 	my $useGnuCp = $gnucp and ($md5sum eq 'socket' or
 				   $md5sum eq 'blockdev' or
@@ -505,7 +480,7 @@ while ((($md5sum, $compr, $devInode, $inodeBackup, $ctime, $mtime, $atime,
 	{
 	    unless ($noHardLinks)
 	    {
-		if (defined($DBMHardLink{$devInode}))   # muss nur gelinkt werden
+		if (exists($DBMHardLink{$devInode}))   # muss nur gelinkt werden
 		{
 		    if (link $DBMHardLink{$devInode}, $targetFile)
 		    {
@@ -524,7 +499,6 @@ while ((($md5sum, $compr, $devInode, $inodeBackup, $ctime, $mtime, $atime,
 				      ["failed: link " .
 				       $DBMHardLink{$devInode} .
 				       " $targetFile"]);
-			$exit = 1;
 		    }
 		    goto contLoop;
 		}
@@ -534,71 +508,58 @@ while ((($md5sum, $compr, $devInode, $inodeBackup, $ctime, $mtime, $atime,
 		}
 	    }
 	    my $linkTo = readlink "$backupRoot/$filename";
-
-	    ++$noSymLinks;
-	    symlink $linkTo, $targetFile;
-
-	    # bei einigen Betriebssystem (z.B. Linux) wird bei Aufruf
-	    # des Systemcalls chmod bei symlinks nicht der Symlink selbst
-	    # geaendert, sondern die Datei, auf die er verweist.
-	    # (dann muss lchown genommen werden -> Inkompatibilitaeten!?)
-	    my $chown = forkProc->new('-exec' => 'chown',
-				      '-param' => ['-h', "$uid:$gid",
-						   "$targetFile"],
-				      '-outRandom' => "$tmpdir/chown-",
-				      '-prLog' => $prLog);
-	    $chown->wait();
-#	    utime $atime, $mtime, $targetFile;
-	    $prLog->print('-kind' => 'I',
-			  '-str' => ["ln -s $linkTo $targetFile"])
-		if ($verbose);
-	}
-	elsif ($md5sum eq 'pipe')
-	{
-	    if ($specialTypeArchiver and
-		$archiveTypes =~ /p/)
+	    if (not $overwrite and -e $targetFile)
 	    {
-		&::extractFileFromArchive($filename, $targetDir, $backupRoot,
-		    $specialTypeArchiver, $prLog, $tmpdir);
-		$prLog->print('-kind' => 'I',
-			      '-str' =>
-	     ["$specialTypeArchiver $backupRoot/$filename -> $targetFile"])
-		    if ($verbose);
+		$prLog->print('-kind' => 'W',
+			      '-str' => ["target $targetFile already exists:",
+					 "\tln -s $linkTo $targetFile"]);
 	    }
 	    else
 	    {
-		my $mknod = forkProc->new('-exec' => 'mknod',
-					  '-param' => ["$targetFile", 'p'],
-					  '-outRandom' => "$tmpdir/mknod-",
-					  '-prLog' => $prLog);
-		$mknod->wait();
-		my $out = $mknod->getSTDOUT();
-		$prLog->print('-kind' => 'E',
-			      '-str' =>
-			      ["STDOUT of <mknod $targetFile p>:", @$out])
-		    if (@$out > 0);
-		$out = $mknod->getSTDERR();
-		if (@$out > 0)
-		{
-		    $prLog->print('-kind' => 'E',
-				  '-str' =>
-				  ["STDERR of <mknod $targetFile p>:", @$out]);
-			$exit = 1;
-		}
-		chown $uid, $gid, $targetFile;
-		chmod $mode, $targetFile;
-		utime $atime, $mtime, $targetFile;
-		$prLog->print('-kind' => 'I',
-			      '-str' =>
-			      ["mknod $targetFile p"])
-		    if ($verbose);
+		++$noSymLinks;
+		symlink $linkTo, $targetFile;
 
+		# bei einigen Betriebssystem (z.B. Linux) wird bei Aufruf
+		# des Systemcalls chmod bei symlinks nicht der Symlink selbst
+		# geaendert, sondern die Datei, auf die er verweist.
+		# (dann muss lchown genommen werden -> Inkompatibilitaeten!?)
+		my $chown = forkProc->new('-exec' => 'chown',
+					  '-param' => ['-h', "$uid:$gid",
+						       "$targetFile"],
+					  '-outRandom' => "$tmpdir/chown-",
+					  '-prLog' => $prLog);
+		$chown->wait();
+#		utime $atime, $mtime, $targetFile;
+		$prLog->print('-kind' => 'I',
+			      '-str' => ["ln -s $linkTo $targetFile"])
+		    if ($verbose);
 	    }
 	}
-	elsif (length($md5sum) == 32 or            # normal file
-	       $useGnuCp or $specialTypeArchiver)  # special file
+	elsif ($md5sum eq 'pipe')
 	{
-# Idee zur Lsung des parallelitts-Problems beim Zurcksichern
+	    my $mknod = forkProc->new('-exec' => 'mknod',
+				      '-param' => ["$targetFile", 'p'],
+				      '-outRandom' => "$tmpdir/mknod-",
+				      '-prLog' => $prLog);
+	    $mknod->wait();
+	    my $out = $mknod->getSTDOUT();
+	    $prLog->print('-kind' => 'E',
+			  '-str' =>
+			  ["STDOUT of <mknod $targetFile p>:", @$out])
+		if (@$out > 0);
+	    $out = $mknod->getSTDERR();
+	    $prLog->print('-kind' => 'E',
+			  '-str' =>
+			  ["STDERR of <mknod $targetFile p>:", @$out])
+		if (@$out > 0);
+	    chown $uid, $gid, $targetFile;
+	    chmod $mode, $targetFile;
+	    utime $atime, $mtime, $targetFile;
+	}
+	elsif (length($md5sum) == 32 or     # normal file
+	       $useGnuCp)                   # special file
+	{
+# Idee zur Lsung des parallelitts-Prolems beim Zurcksichern
 # in Verbindung mit dem Setzen der hard links:
 # erste Datei:
 # dev-inode => '.' in dbm-file (%DBMHardLink)
@@ -614,7 +575,7 @@ while ((($md5sum, $compr, $devInode, $inodeBackup, $ctime, $mtime, $atime,
 
 	    unless ($noHardLinks) # Hard Link berprfen
 	    {
-		if (defined($DBMHardLink{$devInode}))   # muss nur gelinkt werden
+		if (exists($DBMHardLink{$devInode}))   # muss nur gelinkt werden
 		{
 		    $hasToBeLinked{$targetFile} = [$devInode, $uid, $gid, $mode,
 						   $atime, $mtime];
@@ -643,34 +604,17 @@ while ((($md5sum, $compr, $devInode, $inodeBackup, $ctime, $mtime, $atime,
 		    $noBlockDevs++ if $md5sum eq 'blockdev';
 		    $noCharDevs++ if $md5sum eq 'chardev';
 
-		    if ($specialTypeArchiver and
-			length($md5sum) < 32)
-#			$archiveTypes =~ /[Sbc]/)
-		    {
-			&::extractFileFromArchive($filename, $targetDir, $backupRoot,
-						  $specialTypeArchiver, $prLog,
-						  $tmpdir);
-
-			$prLog->print('-kind' => 'I',
-				      '-str' =>
-		      ["$specialTypeArchiver $backupRoot/$filename -> $targetFile"])
-			    if ($verbose);
-		    }
-		    else
-		    {
-			my $par = [@cpPar, "$backupRoot/$filename", "$targetFile"];
-			($old, $new) =
-			    $fork->add_block('-exec' => $cp,
-					     '-param' => $par,
-					     '-outRandom' => "$tmpdir/recover-",
-					     '-info' => [$targetFile, $uid, $gid, $mode,
-							 $atime, $mtime, $devInode,
-							 [$cp, @$par]]);
-			$prLog->print('-kind' => 'I',
-				      '-str' =>
-				      ["cp $backupRoot/$filename $targetFile"])
-			    if ($verbose);
-		    }
+		    ($old, $new) =
+			$fork->add_block('-exec' => $cp,
+				   '-param' => [@cpPar, "$backupRoot/$filename",
+						"$targetFile"],
+				   '-outRandom' => "$tmpdir/recover-",
+				   '-info' => [$targetFile, $uid, $gid, $mode,
+					       $atime, $mtime, $devInode]);
+		    $prLog->print('-kind' => 'I',
+				  '-str' =>
+				  ["cp $backupRoot/$filename $targetFile"])
+			if ($verbose);
 		}
 	    }
 	    elsif ($compr eq 'c')          # war komprimiert
@@ -687,9 +631,6 @@ while ((($md5sum, $compr, $devInode, $inodeBackup, $ctime, $mtime, $atime,
 		else
 		{
 		    ++$noFilesCompr;
-		    my $comm = [$uncompr, @uncomprPar, '<',
-				"$backupRoot/$filename$postfix", '>',
-				$targetFile];
 		    ($old, $new) =
 			$fork->add_block('-exec' => $uncompr,
 				   '-param' => \@uncomprPar,
@@ -698,7 +639,7 @@ while ((($md5sum, $compr, $devInode, $inodeBackup, $ctime, $mtime, $atime,
 				   '-delStdout' => 'no',
 				   '-outRandom' => "$tmpdir/recover-",
 				   '-info' => [$targetFile, $uid, $gid, $mode,
-					       $atime, $mtime, $devInode, $comm]);
+					       $atime, $mtime, $devInode]);
 		    $prLog->print('-kind' => 'I',
 				  '-str' => ["$uncompr @uncomprPar < " .
 					     "$backupRoot/$filename$postfix > " .
@@ -709,16 +650,13 @@ while ((($md5sum, $compr, $devInode, $inodeBackup, $ctime, $mtime, $atime,
 	    elsif ($compr eq 'b')       # blocked file
 	    {
 		++$noFilesBlocked;
-		my $comm = ["cp (block", "$backupRoot/$filename$postfix",
-			    "$targetFile"];
 		($old, $new) =
 		    $fork->add_block('-function' => \&uncompressCatBlock,
 				     '-funcPar' => ["$backupRoot/$filename",
-				     $backupRoot, $createSparseFiles,
 				     $targetFile, '\A\d.*', $uncompr, \@uncomprPar,
-				     $postfix, $size, $prLog],
+				     $postfix, $prLog],
 				     '-info' => [$targetFile, $uid, $gid, $mode,
-						 $atime, $mtime, $devInode, $comm]);
+						 $atime, $mtime, $devInode]);
 		$prLog->print('-kind' => 'I',
 			      '-str' => ["cp (blocked) " .
 					     "$backupRoot/$filename$postfix " .
@@ -731,7 +669,6 @@ while ((($md5sum, $compr, $devInode, $inodeBackup, $ctime, $mtime, $atime,
 			      '-str' =>
 			      ["unknow compr flag <$compr> in .md5CheckSums " .
 			       "for file <$backupRoot/$filename>"]);
-		$exit = 1;
 	    }
 	    if ($old)
 	    {
@@ -753,7 +690,6 @@ while ((($md5sum, $compr, $devInode, $inodeBackup, $ctime, $mtime, $atime,
 	    $prLog->print('-kind' => 'E',
 			  '-str' =>
 			  ["unknown entry <$md5sum> for file <$filename>:"]);
-	    $exit = 1;
 	}
     }
 
@@ -769,24 +705,8 @@ finish:;
 my $job;
 while ($job = $fork->waitForAllJobs())
 {
-    my ($f, $oUid, $oGid, $oMode, $oAtime, $oMtime, $oDevInode, $comm) =
+    my ($f, $oUid, $oGid, $oMode, $oAtime, $oMtime, $oDevInode) =
 	@{$job->get('-what' => 'info')};
-
-    if (ref($job) eq 'forkProc')
-    {
-	my $out = $job->getSTDERR();
-	if (@$out > 0)
-	{
-	    $prLog->print('-kind' => 'E',
-			  '-str' => ["STDERR of: @$comm", @$out]);
-	    $exit = 1;
-	}
-	if ($job->get('-what' => 'status'))
-	{
-	    $exit = 1;
-	}
-    }
-
     unless ($noHardLinks)
     {                                 # File in DBM vermerken
 	$DBMHardLink{$oDevInode} = $f;
@@ -810,7 +730,6 @@ unless (open(DIRFILE, '<', $tmpDirFile))
     $prLog->print('-kind' => 'E',
 		  '-str' => ["cannot read <$tmpDirFile>, cannot set " .
 			     "atime and mtime for directories"]);
-    $exit = 1;
 }
 else
 {
@@ -848,7 +767,7 @@ $prLog->print('-kind' => 'I',
     )
     if ($noRestored);
 
-exit $exit;
+exit 0;
 
 
 ############################################################
@@ -860,7 +779,7 @@ sub setHardLinks
     foreach $f (keys %$hasToBeLinked)
     {
 	my ($di, $uid, $gid, $mode, $atime, $mtime) = @{$$hasToBeLinked{$f}};
-	if (defined($$DBMHardLink{$di}) and $$DBMHardLink{$di} ne '.')
+	if (exists($$DBMHardLink{$di}) and $$DBMHardLink{$di} ne '.')
 	{
 	    my $oldF = $$DBMHardLink{$di};
 	    if (-e $f)
@@ -895,133 +814,76 @@ sub setHardLinks
 sub uncompressCatBlock
 {
     my $fromDir = shift;
-    my $backupRoot = shift;
-    my $createSparseFiles = shift;
     my $toFile = shift;
     my $mask = shift;
     my $umcompr = shift;
     my $uncomprPar = shift;
     my $postfix = shift;
-    my $size = shift;
     my $prLog = shift;
 
-    my $nBlocks = 0;
-    my (@entries, @md5, @compr);
-
-    my $fileIn =
-	pipeFromFork->new('-exec' => 'bzip2',
-			  '-param' => ['-d'],
-			  '-stdin' => "$fromDir/.md5BlockCheckSums.bz2",
-			  '-outRandom' => "$tmpdir/stbuPipeFrom11-",
-			  '-prLog' => $prLog);
-    my $l;
-    while ($l = $fileIn->read())
+    local *DIR;
+    unless (opendir(DIR, $fromDir))
     {
-	my ($l_md5, $l_compr, $l_f, $n);
-	chomp $l;
-	$n = ($l_md5, $l_compr, $l_f) = split(/\s/, $l, 3);
-	if ($n != 3)
-	{
-	    $prLog->print('-kind' => 'E',
-			  '-str' =>
-			  ["strange line in <$fromDir/.md5BlockCheckSums.bz2> " .
-			   "in line " . $fileIn->get('-what' => 'lineNr') .
-			   ":", "\t<$l>"]);
-	    return 1;
-	}
-	++$nBlocks;
-	push @md5, $l_md5;
-	push @compr, $l_compr;
-	push @entries, $l_f;
+	$prLog->print('-kind' => 'E',
+		      '-str' => ["cannot open <$fromDir>"]);
+	return 1;
     }
-    $fileIn->close();
-    $fileIn = undef;
+    my ($entry, @entries);
+    while ($entry = readdir DIR)
+    {
+	next unless $entry =~ /$mask/;
 
-    &::createSparseFile($toFile, $size, $prLog) or exit 1;
+	push @entries, $entry;
+    }
+    close(DIR);
 
-    my $md5null = '';
-
-    my $ret = 0;
     local *TO;
     unless (sysopen(TO, $toFile, O_CREAT | O_WRONLY))
     {
 	$prLog->print('-kind' => 'E',
 		      '-str' => ["cannot write to <$toFile>"]);
-	$ret = 1;
     }
 
-    my $blockSize = 0;
-    for (my $iBlock = 0 ; $iBlock < @entries ; ++$iBlock)
+    foreach $entry (sort @entries)
     {
-	my $entry = $entries[$iBlock];
-	my $md5 = $md5[$iBlock];
-	my $compr = $compr[$iBlock];
-	my $actSeekPos = $blockSize * $iBlock;
-
-	sysseek(TO, $actSeekPos, 0);
-
-	next if ($md5 eq $md5null);
-
 	my $buffer;
 	local *FROM;
 	my $fileIn = undef;
-	if ($compr eq 'c')       # compressed block
+	if ($entry =~ /$postfix\Z/)    # compressed block
 	{
 	    if ($main::IOCompressDirect)
 	    {
-		my $input = "$backupRoot/$entry";
+		my $input = "$fromDir/$entry";
 		my $uc = new IO::Uncompress::Bunzip2 $input;
 		while ($uc->read($buffer, 10*1024**2))
 		{
-		    my $n;
-		    unless ($n = syswrite(TO, $buffer))
-		    {
-			$prLog->print('-kind' => 'E',
-				      '-str' => ["writing to <$toFile> failed"]);
-			$ret = 1;
-		    }
-		    $blockSize += $n if $iBlock == 0;
+		    syswrite(TO, $buffer);
 		}
+		next;
 	    }
-	    else
+
+	    $fileIn =
+		pipeFromFork->new('-exec' => $uncompr,
+				  '-param' => \@uncomprPar,
+				  '-stdin' => "$fromDir/$entry",
+				  '-outRandom' => '/tmp/stbuPipeFrom11-',
+				  '-prLog' => $prLog);
+	    while ($fileIn->sysread(\$buffer, 10*1024**2))
 	    {
-		$fileIn =
-		    pipeFromFork->new('-exec' => $uncompr,
-				      '-param' => \@uncomprPar,
-				      '-stdin' => "$backupRoot/$entry",
-				      '-outRandom' => "$tmpdir/stbuPipeFrom11-",
-				      '-prLog' => $prLog);
-		while ($fileIn->sysread(\$buffer, 10*1024**2))
-		{
-		    my $n;
-		    unless ($n = syswrite(TO, $buffer))
-		    {
-			$prLog->print('-kind' => 'E',
-				      '-str' => ["writing to <$toFile> failed"]);
-			$ret = 1;
-		    }
-		    $blockSize += $n if $iBlock == 0;
-		}
+		syswrite(TO, $buffer);
 	    }
 	}
 	else           # block not compressed
 	{
-	    unless (sysopen(FROM, "$backupRoot/$entry", O_RDONLY))
+	    unless (sysopen(FROM, "$fromDir/$entry", O_RDONLY))
 	    {
 		$prLog->print('-kind' => 'E',
-			      '-str' => ["cannot read <$backupRoot/$entry>"]);
+			      '-str' => ["cannot read <$fromDir/$entry>"]);
 		return 1;
 	    }
 	    while (sysread(FROM, $buffer, 10*1024**2))
 	    {
-		my $n;
-		unless ($n = syswrite(TO, $buffer))
-		{
-		    $prLog->print('-kind' => 'E',
-				  '-str' => ["writing to <$toFile> failed"]);
-		    $ret = 1;
-		}
-		$blockSize += $n if $iBlock == 0;
+		syswrite(TO, $buffer);
 	    }
 	}
 
@@ -1034,27 +896,7 @@ sub uncompressCatBlock
 	{
 	    close(FROM);
 	}
-
-	if ($iBlock == 0)
-	{
-	    $md5null = &::calcMD5null($blockSize)
-		if $createSparseFiles;
-	}
     }
     close(TO);
-    return $ret;
-}
-
-
-############################################################
-# calc md5 sum of block with $size time zero
-sub calcMD5null
-{
-    my $size = shift;
-
-    my $null = pack('C', 0) x $size;
-
-    my $md5 = Digest::MD5->new();
-    $md5->add($null);
-    return $md5->hexdigest();
+    return 0;
 }
