@@ -1,7 +1,7 @@
 #! /usr/bin/env perl
 
 #
-#   Copyright (C) Dr. Heinz-Josef Claes (2012-2020)
+#   Copyright (C) Dr. Heinz-Josef Claes (2012)
 #                 hjclaes@web.de
 #   
 #   This program is free software: you can redistribute it and/or modify
@@ -96,10 +96,6 @@ require 'forkProc.pl';
 require 'dateTools.pl';
 require 'version.pl';
 require 'tail.pl';
-require 'fileDir.pl';
-
-my $tmpdir = '/tmp';              # default value
-$tmpdir = $ENV{'TMPDIR'} if defined $ENV{'TMPDIR'};
 
 
 my $commentMasterBackup =
@@ -125,7 +121,7 @@ storeBackupReplicationWizard.pl - creates configuration files for replication
 =head1 SYNOPSIS
 
     storeBackupReplicationWizard.pl [-m masterBackupDir]
-          [-c backupCopyDir] [-d deltaCacheDir] [-S series] [-T tmpdir]
+          [-c backupCopyDir] [-d deltaCacheDir] [-S series]
 
 =head1 DESCRIPTION
 
@@ -158,24 +154,22 @@ create them
     series to be replicated
     use this parameter multiple times for multiple series
 
-=item B<--tmpdir>, B<-T>
-
-    directory for temporary files, default is </tmp>
-
 =back
 
 =head1 COPYRIGHT
 
-Copyright (c) 2012-2020 by Heinz-Josef Claes (see README).
+Copyright (c) 2012 by Heinz-Josef Claes (see README).
 Published under the GNU General Public License v3 or any later version
 
 =cut
 
 my $binPath = &::absolutePath("$req/../bin");
 
-my $Help = &::getPod2Text($0);
+my $Help = join('', grep(!/^\s*$/, `pod2text $0`));
+$Help = "cannot find pod2text, see documentation for details\n"
+    unless $Help;
 
-&printVersion(\@ARGV, '-V', '--version');
+&printVersion(\@ARGV, '-V');
 
 my $CheckPar =
     CheckParam->new('-list' =>
@@ -195,11 +189,7 @@ my $CheckPar =
 				 '-cl_option' => '-S',
 				 '-cl_alias' => '--series',
 				 '-param' => 'yes',
-				 '-multiple' => 'yes'),
-		     Option->new('-name' => 'tmpdir',
-				 '-cl_option' => '-T',
-				 '-cl_alias' => '--tmpdir',
-				 '-default' => $tmpdir)
+				 '-multiple' => 'yes')
 		    ]
     );
 
@@ -225,7 +215,6 @@ my $backupCopyDir = $CheckPar->getOptWithPar('backupCopyDir');
 my $deltaCacheDir = $CheckPar->getOptWithPar('deltaCacheDir');
 my $series = $CheckPar->getOptWithPar('series');
 (@$series) = sort (@$series) if $series;
-$tmpdir = $CheckPar->getOptWithPar('tmpdir');
 
 #
 # check if parameters are set
@@ -314,7 +303,7 @@ my (@seriesFound) = ();
 	$prLog->print('-kind' => 'W',
 		      '-str' =>
 		      ["cannot find any existing backup at " .
-		       "master backup directory <$masterBackupDir>"]);
+		       "master backup directory <masterBackupDir>"]);
 	unless ($masterBackupDirPreset)
 	{
 	    my $answer = undef;
@@ -451,7 +440,7 @@ $prLog->print('-kind' => 'I',
 #
 # generate configuration files
 #
-my $tmpDir = &::uniqFileName("$tmpdir/stbuRW-");
+my $tmpDir = &::uniqFileName('/tmp/stbuRW-');
 mkdir $tmpDir, 0700 or
     $prLog->print('-kind' => 'E',
 		  '-str' => ["cannot create temporary directory <$tmpDir>"],
