@@ -1,7 +1,7 @@
 #! /usr/bin/env perl
 
 #
-#   Copyright (C) Dr. Heinz-Josef Claes (2008-2009)
+#   Copyright (C) Dr. Heinz-Josef Claes (2008-2012)
 #                 hjclaes@web.de
 #   
 #   This program is free software: you can redistribute it and/or modify
@@ -19,9 +19,6 @@
 #
 
 
-my $VERSION = '$Id: storeBackupSearch.pl 341 2008-07-31 13:13:17Z hjc $ ';
-push @VERSION, $VERSION;
-my ($VERSIONpName, $VERSIONsvnID) = $VERSION =~ /Id:\s+(\S+)\s+(\d+)/;
 $main::STOREBACKUPVERSION = undef;
 
 
@@ -110,7 +107,7 @@ storeBackupSearch.pl - locates different versions of a file saved with storeBack
 
 	storeBackupSearch.pl -g configFile
 
-	storeBackupSearch.pl [-f configFile] [-b backupDirDir]
+	storeBackupSearch.pl -b backupDirDir [-f configFile]
 	      [-s rule]  [--absPath] [-w file] [--parJobs number]
 	      [-d level] [--once] [--print] [backupRoot . . .]
 
@@ -135,7 +132,7 @@ You need some basic understanding of linux and perl to use it.
     configuration file (instead of or
     additionally to parameters)
 
-=item B<--backupDir> F<backupDirDir>, B<-b> F<backupDirDir>
+=item B<--backupDir> B<-b>
 
 		    top level directory of all backups
 
@@ -174,7 +171,7 @@ You need some basic understanding of linux and perl to use it.
 
 =head1 COPYRIGHT
 
-Copyright (c) 2008-2009 by Heinz-Josef Claes (see README).
+Copyright (c) 2008-2012 by Heinz-Josef Claes (see README).
 Published under the GNU General Public License v3 or any later version
 
 =cut
@@ -184,7 +181,7 @@ $Help = "cannot find pod2text, see documentation for details\n"
     unless $Help;
 
 my $templateConfigFile = <<EOC;
-# configuration file for storeBackup.pl
+# configuration file for storeBackupSearch.pl, version $main::STOREBACKUPVERSION
 
 # You can set a value specified with '-cf_key' (eg. logFiles) and
 # continue at the next lines which have to begin with a white space:
@@ -227,7 +224,7 @@ my $templateConfigFile = <<EOC;
 
 # write result with absolute path names
 # default is 'no', possible values are 'yes' and 'no'
-;absPath
+;absPath=
 
 # write search result also to file
 ;writeToFile=
@@ -245,7 +242,7 @@ EOC
     ;
 
 
-&printVersions(\@ARGV, '-V');
+&printVersion(\@ARGV, '-V');
 
 my $CheckPar =
     CheckParam->new('-configFile' => '-f',
@@ -385,10 +382,10 @@ if ($print)
 
 my $prLog = printLog->new('-kind' => ['I:INFO', 'W:WARNING', 'E:ERROR',
 				      'S:STATISTIC', 'D:DEBUG', 'V:VERSION']);
+$prLog->fork($req);
 
 $prLog->print('-kind' => 'V',
-	      '-str' => ["$VERSIONpName, $main::STOREBACKUPVERSION, " .
-			 "build $VERSIONsvnID"]);
+	      '-str' => ["storeBackupSearch.pl, $main::STOREBACKUPVERSION"]);
 
 $prLog->print('-kind' => 'E',
 	      '-str' => ["missing parameters backupDir and searchRule\n$Help"],
@@ -529,8 +526,9 @@ foreach $dirToSearch (@dirsToSearch)
     my $rcsf =
 	readCheckSumFile->new('-checkSumFile' => "$dirToSearch/$checkSumFile",
 			      '-prLog' => $prLog);
-    my $meta = $rcsf->getMetaValField();
-    my $postfix = ($$meta{'postfix'})->[0];    # postfix for compression
+#    my $meta = $rcsf->getMetaValField();
+#    my $postfix = ($$meta{'postfix'})->[0];    # postfix for compression
+    my $postfix = $rcsf->getInfoWithPar('postfix');
 
     my $jobToDo = 1;
     my $parForkToDo = 1;
