@@ -1,7 +1,7 @@
 #!/usr/bin/env perl
 
 #
-#   Copyright (C) Dr. Heinz-Josef Claes (2012-2020)
+#   Copyright (C) Dr. Heinz-Josef Claes (2012)
 #                 hjclaes@web.de
 #
 #   This program is free software: you can redistribute it and/or modify
@@ -118,14 +118,13 @@ storeBackupMergeIsolatedBackup.pl and storeBackupUpdateBackup.pl
 based on configuration file:
 
     storeBackupSetupIsolatedMode.pl -f configFile -t targetDir
-    				[-S series] [-g newConfigFile]
-				[-e explicitBackup] [-v] [-F]
+    				[-S series] [-g newConfigFile] [-v]
 
 
 no configuration file:
 
     storeBackupSetupIsolatedMode.pl -b backupDir -t targetDir
-    				[-S series] [-e explicitBackup] [-v] [-F]
+    				[-S series] [-v]
 
 =head1 OPTIONS
 
@@ -134,9 +133,7 @@ no configuration file:
 =item B<--configFile>, B<-f>
 
     (original, non-isolated mode) configuration file to copy for
-    isolated mode also used to get value for backupDir and series.
-    You can also use an already generated configuration file to
-    repeat the set up with the same configuration as in the past.
+    isolated mode also used to get value for backupDir and series
 
 =item B<--targetDir>, B<-t>
 
@@ -164,32 +161,24 @@ no configuration file:
     Has to be specified if more than one series exist
     in backupDir
 
-=item B<--explicitBackup>, B<-e>
-
-    explicit Backup which has to be copied
-    default is the last backup of the specified series
-
 =item B<--verbose>, B<-v>
 
     generate verbose messages
 
-=item B<--force>, B<-F>
-
-    force usage of last backup (with lateLinks), even it if has
-    not been completed with storeBackupUpdateBackup.pl
-
 =back
 
 =head1 COPYRIGHT
 
-Copyright (c) 2012-2020 by Heinz-Josef Claes (see README).
+Copyright (c) 2012 by Heinz-Josef Claes (see README).
 Published under the GNU General Public License v3 or any later version
 
 =cut
 
-my $Help = &::getPod2Text($0);
+my $Help = join('', grep(!/^\s*$/, `pod2text $0`));
+$Help = "cannot find pod2text, see documentation for details\n"
+    unless $Help;
 
-&printVersion(\@ARGV, '-V', '--version');
+&printVersion(\@ARGV, '-V');
 
 my $CheckPar =
     CheckParam->new('-allowLists' => 'no',
@@ -203,10 +192,6 @@ my $CheckPar =
 					    '-cl_alias' => '--series',
 					    '-param' => 'yes',
 					    '-only_if' => '[backupDir]'),
-				Option->new('-name' => 'explicitBackup',
-					    '-cl_option' => '-e',
-					    '-cl_alias' => '--explicitBackup',
-					    '-param' => 'yes'),
 				Option->new('-name' => 'configFile',
 					    '-cl_option' => '-f',
 					    '-cl_alias' => '--configFile',
@@ -216,8 +201,7 @@ my $CheckPar =
 					    '-cl_option' => '-t',
 					    '-cl_alias' => '--targetDir',
 					    '-param' => 'yes',
-#					    '-must_be' => 'yes'),
-					    ),
+					    '-must_be' => 'yes'),
 				Option->new('-name' => 'generate',
 					    '-cl_option' => '-g',
 					    '-cl_alias' => '--generate',
@@ -225,10 +209,7 @@ my $CheckPar =
 					    '-only_if' => '[configFile]'),
 				Option->new('-name' => 'verbose',
 					    '-cl_option' => '-v',
-					    '-cl_alias' => '--verbose'),
-				Option->new('-name' => 'force',
-					    '-cl_option' => '-F',
-					    '-cl_alias' => '--force')
+					    '-cl_alias' => '--verbose')
 				]);
 
 $CheckPar->check('-argv' => \@ARGV,
@@ -238,12 +219,10 @@ $CheckPar->check('-argv' => \@ARGV,
 my $backupDir = $CheckPar->getOptWithPar('backupDir');
 my $series = $CheckPar->getOptWithPar('series');  # must be specified if
                                                   # more than 1 series exist
-my $explicitBackup = $CheckPar->getOptWithPar('explicitBackup');
 my $configFile = $CheckPar->getOptWithPar('configFile');
 my $generateConfigFile = $CheckPar->getOptWithPar('generate');
 my $targetDir = $CheckPar->getOptWithPar('targetDir');
 my $verbose = $CheckPar->getOptWithoutPar('verbose');
-my $force = $CheckPar->getOptWithoutPar('force');
 
 
 my $prLog;
@@ -260,11 +239,15 @@ $prLog->print('-kind' => 'E',
 	      '-exit' => 1)
     unless ($configFile or $backupDir);
 
+$prLog->print('-kind' => 'E',
+	      '-str' => ["target directory <$targetDir> does not exist"],
+	      '-exit' => 1)
+    unless (-d $targetDir);
+
 
 my $otherBackupSeries = undef;
 my $lateLinks = undef;
 my $lateCompress = undef;
-my $useOldConfig = 0;
 if ($configFile)    # get information from config file
 {
     my $confOld =
@@ -285,26 +268,13 @@ if ($configFile)    # get information from config file
 			    Option->new('-name' => 'lateCompress',
 					'-only_if' => '[lateLinks]',
 					'-cf_key' => 'lateCompress',
-					'-cf_noOptSet' => ['yes', 'no']),
-			    Option->new('-name' => 'mergeBackupDir',
-					'-cf_key' => 'mergeBackupDir',
-					'-param' => 'yes'),
+					'-cf_noOptSet' => ['yes', 'no'])
 			]);
     $confOld->check('-argv' => ['-f' => $configFile],
 		    '-help' => "cannot read file <$configFile>\n",
 		    '-ignoreAdditionalKeys' => 1);
 
-    my $mergeBackupDir = $confOld->getOptWithPar('mergeBackupDir');
-    if ($mergeBackupDir)
-    {
-	$backupDir = $confOld->getOptWithPar('mergeBackupDir');
-	$targetDir = $confOld->getOptWithPar('backupDir');
-	$useOldConfig = 1;
-    }
-    else
-    {
-	$backupDir = $confOld->getOptWithPar('backupDir');
-    }
+    $backupDir = $confOld->getOptWithPar('backupDir');
     $series = $confOld->getOptWithPar('series');
     $lateLinks = $confOld->getOptWithoutPar('lateLinks');
     $lateCompress = $confOld->getOptWithoutPar('lateCompress');
@@ -350,14 +320,6 @@ $prLog->print('-kind' => 'E',
 	      '-str' => ["backup directory <$backupDir> does not exist"],
 	      '-exit' => 1)
     unless (-d $backupDir);
-$prLog->print('-kind' => 'E',
-	      '-str' => ["please specify targetDir"],
-	      '-exit' => 1)
-    unless ($targetDir);
-$prLog->print('-kind' => 'E',
-	      '-str' => ["target directory <$targetDir> does not exist"],
-	      '-exit' => 1)
-    unless (-d $targetDir);
 $prLog->print('-kind' => 'E',
 	      '-str' =>
 	      ["series directory <$series> does not exist inside <$backupDir>"],
@@ -374,15 +336,6 @@ my $targetSeriesDir = "$targetDir/$series";
 # detect last backup
 #
 my $lastBackupDir = undef;
-if ($explicitBackup)
-{
-    $lastBackupDir = "$backupDir/$series/$explicitBackup";
-    $prLog->print('-kind' => 'E',
-		  '-str' => ["explicit backup <$lastBackupDir> does not exist"],
-		  '-exit' => 1)
-	unless -d $lastBackupDir;
-}
-else
 {
     local *DIR;
     opendir(DIR, "$backupDir/$series") or
@@ -404,10 +357,7 @@ else
     my $e;
     foreach $e (@entries)
     {
-#	if (-e "$backupDir/$series/$e/.md5CheckSums.notfinished")
-	unless (&::checkIfBackupWasFinished('-backupDir' => "$backupDir/$series/$e",
-					    '-prLog' => $prLog,
-			    '-count' => 50))
+	if (-e "$backupDir/$series/$e/.md5CheckSums.notfinished")
 	{
 	    $prLog->print('-kind' => 'W',
 			  '-str' => ["<$backupDir/$series/$e> not finished"]);
@@ -425,13 +375,10 @@ else
 
     $prLog->print('-kind' => 'E',
 		  '-str' =>
-       ["last backupDir <$backupDir> needs",
-	"to run storeBackupUpdateBackup.pl, ",
-	"please do so and repeat running this program",
-	"or use option --explicitBackup or option --force"],
+       ["last backupDir <$backupDir> needs to run storeBackupUpdateBackup.pl, " .
+	"please do so and repeat running this program"],
 		  '-exit' => 1)
-	if -e "$lastBackupDir/.storeBackupLinks/linkFile.bz2"
-	and not $force;
+	if -e "$lastBackupDir/.storeBackupLinks/linkFile.bz2";
 
     $prLog->print('-kind' => 'I',
 		  '-str' =>
@@ -439,7 +386,7 @@ else
 	if $verbose;
 }
 
-if ($configFile and not $useOldConfig)  # copy configuration file
+if ($configFile)  # copy configuration file
 {
     unless ($generateConfigFile)
     {
@@ -625,14 +572,87 @@ $prLog->print('-kind' => 'I',
 	      '-str' => ["created directory <$targetBackupDir>"])
     if $verbose;
 
-&::copyStbuSpecialFiles($lastBackupDir, $targetBackupDir, $prLog, $verbose,
-			'/tmp');
+$prLog->print('-kind' => 'E',
+	      '-str' => ["cannot create directory " .
+			 "<$targetBackupDir/.storeBackupLinks>"],
+	      '-exit' => 1)
+    unless mkdir "$targetBackupDir/.storeBackupLinks", 0700;
+$prLog->print('-kind' => 'I',
+	      '-str' => ["created directory " .
+			 "<$targetBackupDir/.storeBackupLinks>"])
+    if $verbose;
+
+my $f = undef;
+if (-f "$lastBackupDir/.md5CheckSums")
+{
+    $f = ".md5CheckSums";
+}
+elsif (-f "$lastBackupDir/.md5CheckSums.bz2")
+{
+    $f = ".md5CheckSums.bz2";
+}
+$prLog->print('-kind' => 'E',
+	      '-str' => ["cannot read <$lastBackupDir/.md5CheckSums[.bz2]>"],
+	      '-exit' => 1)
+    unless $f;
+
+&copyFilePerm("$lastBackupDir/$f" => $targetBackupDir, $prLog, $verbose);
+&copyFilePerm("$lastBackupDir/.md5CheckSums.info" => $targetBackupDir,
+	      $prLog, $verbose);
+
+$f = "$lastBackupDir/.md5BlockCheckSums.bz2";
+&copyFilePerm($f => $targetBackupDir, $prLog, $verbose)
+    if -e $f;
+
+my $rcsf = readCheckSumFile->new('-checkSumFile' =>
+				 "$lastBackupDir/.md5CheckSums",
+				 '-prLog' => $prLog);
+my ($md5sum, $compr, $devInode, $inodeBackup, $ctime, $mtime, $atime,
+    $size, $uid, $gid, $mode, $filename);
+while ((($md5sum, $compr, $devInode, $inodeBackup, $ctime, $mtime,
+	 $atime, $size, $uid, $gid, $mode, $filename) =
+	$rcsf->nextLine()) > 0)
+{
+    if ($compr eq 'b')     # blocked file
+    {
+	$f = undef;
+	if (-f "$lastBackupDir/$filename/.md5BlockCheckSums")
+	{
+	    $f = ".md5BlockCheckSums";
+	}
+	elsif (-f "$lastBackupDir/$filename/.md5BlockCheckSums.bz2")
+	{
+	    $f = ".md5BlockCheckSums.bz2";
+	}
+
+	&::makeDirPath("$targetBackupDir/$filename", $prLog);
+	&copyFilePerm("$lastBackupDir/$filename/$f"
+		      => "$targetBackupDir/$filename",
+		      $prLog, $verbose);
+    }
+}
 
 $prLog->print('-kind' => 'I',
 	      '-str' =>
 	      ["you may want to adjust <$generateConfigFile> to your needs"])
-    if ($configFile and not $useOldConfig);
+    if ($configFile);
 
 
 exit 0;
 
+
+
+##################################################
+sub copyFilePerm
+{
+    my ($source, $target, $prLog, $verbose) = @_;
+
+    $prLog->print('-kind' => 'E',
+		  '-str' => ["cannot copy $source -> $target"],
+		  '-exit' => 1)
+	if system("cp -a \"$source\" \"$target\"");
+    $prLog->print('-kind' => 'I',
+		  '-str' => ["copied $source -> $target"])
+	if $verbose;
+}
+
