@@ -1,7 +1,7 @@
 #! /usr/bin/env perl
 
 #
-#   Copyright (C) Dr. Heinz-Josef Claes (2008-2020)
+#   Copyright (C) Dr. Heinz-Josef Claes (2008-2012)
 #                 hjclaes@web.de
 #
 #   This program is free software: you can redistribute it and/or modify
@@ -99,9 +99,7 @@ require 'dateTools.pl';
 require 'fileDir.pl';
 require 'humanRead.pl';
 
-my $lockFile = ($ENV{'USER'} eq 'root') ?     # default value
-		'/var/lock/storeBackup.lock' :
-		$ENV{'HOME'} . '/storeBackup.lock';
+my $lockFile = '/tmp/storeBackup.lock';   # default value
 my $checkSumFile = '.md5CheckSums';
 my $blockCheckSumFile = '.md5BlockCheckSums';
 my $baseTreeConf = "storeBackupBaseTree.conf";
@@ -120,10 +118,9 @@ storeBackupUpdateBackup.pl - updates / finalizes backups created by storeBackup.
 	      [--print] [--verbose] [--debug] [--lockFile] [--noCompress]
 	      [--progressReport number] [--checkOnly] [--copyBackupOnly]
 	      [--dontCopyBackup] [-A archiveDurationDeltaCache]
-	      [--dontDelInDeltaCache] [--createNewSeries]
-	      [--noWarningDiffSeriesInBackupCopy] [--maxHardLinks]
+	      [--dontDelInDeltaCache]
 	      [--logFile
-	       [--plusLogStdout] [--suppressTime] [-m maxFilelen]
+	       [--suppressTime] [-m maxFilelen]
 	       [[-n noOfOldFiles] | [--saveLogs]]
 	       [--compressWith compressprog]]
 
@@ -176,11 +173,6 @@ storeBackupUpdateBackup.pl - updates / finalizes backups created by storeBackup.
     If set to the same file as in storeBackup it will
     prevent $prog from running in parallel
     to storeBackup, default is $lockFile
-    this type of lock files does not work across multiple servers
-    and is not designed to separate storeBackup.pl and
-    storeBackupUpdateBackup.pl or any other storeBackup
-    process in a separate PID space
-    Default lock file for root is in /var/lock, for others in \$HOME
 
 =item B<--noCompress>
 
@@ -215,13 +207,6 @@ storeBackupUpdateBackup.pl - updates / finalizes backups created by storeBackup.
 =item B<--dontDelInDeltaCache>
     do not delete any backup in deltaCache
 
-=item B<--createNewSeries> B<-C>
-
-    Automatically create new series in deltaCache and the
-    replication directory / directories. This is especially useful
-    if you use wildcards to specify series name which should be
-    added 'on the fly'
-
 =item B<--progressReport>
 
     print progress report:
@@ -236,26 +221,10 @@ storeBackupUpdateBackup.pl - updates / finalizes backups created by storeBackup.
 
 =back
 
-=item B<--noWarningDiffSeriesInBackupCopy>, B<-N>
-
-    do not write a warning if there is a different set of series
-    inside the backup copy (replication directory) than in the
-    actual deltaCache
-
-=item B<--maxHardLinks>
-
-    maximum number of hard links to use
-    zero (default) means limit depends on file system used only
-
 =item B<--logFile>, B<-l>
 
     logFile, Default: stdout
 
-=item B<--plusLogStdout>
-
-    if you specify a log file with --logFile you can
-    additionally print the output to STDOUT with this flag
-
 =item B<--suppressTime>
 
     suppress output of time in logfile
@@ -271,7 +240,7 @@ storeBackupUpdateBackup.pl - updates / finalizes backups created by storeBackup.
 =item B<--saveLogs>
 
     save log files with date and time instead of deleting the
-    old (with [-noOfOldFiles])
+    old (with [-noOldFiles])
 
 =item B<--compressWith>
 
@@ -292,14 +261,16 @@ storeBackupUpdateBackup.pl - updates / finalizes backups created by storeBackup.
 
 =head1 COPYRIGHT
 
-Copyright (c) 2008-2020 by Heinz-Josef Claes.
+Copyright (c) 2008-2012 by Heinz-Josef Claes.
 Published under the GNU General Public License v3 or any later version
 
 =cut
 
-my $Help = &::getPod2Text($0);
+my $Help = join('', grep(!/^\s*$/, `pod2text $0`));
+$Help = "cannot find pod2text, see documentation for details\n"
+    unless $Help;
 
-&printVersion(\@ARGV, '-V', '--version');
+&printVersion(\@ARGV, '-V');
 
 my $startDate = dateTools->new();
 my $CheckPar =
@@ -343,10 +314,6 @@ my $CheckPar =
                                 Option->new('-name' => 'dontDelInDeltaCache',
 					    '-cl_option' => '--dontDelInDeltaCache',
 					    '-only_if' => 'not [interactive]'),
-				Option->new('-name' => 'createNewSeries',
-					    '-cl_option' => '-C',
-					    '-only_if' => 'not [interactive]',
-					    '-cl_alias' => '--createNewSeries'),
 				Option->new('-name' => 'progressReport',
 					    '-cl_option' => '--progressReport',
 					    '-default' => 0,
@@ -357,24 +324,13 @@ my $CheckPar =
 					    '-cl_alias' => '--verbose'),
 				Option->new('-name' => 'debug',
 					    '-cl_option' => '--debug',
-					    '-cl_alias' => '-d',
+					    '-cl_option' => '-d',
 					    '-only_if' => 'not [interactive]'),
-				Option->new('-name' => 'noWarningDiffSeriesInBackupCopy',
-					    '-cl_option' => '-N',
-					    '-only_if' => 'not [interactive]',
-					    '-cl_alias' => '--noWarningDiffSeriesInBackupCopy'),
-				Option->new('-name' => 'maxHardLinks',
-					    '-cl_option' => '--maxHardLinks',
-					    '-default' => 0,
-					    '-pattern' => '\A\d+\Z'),
 				Option->new('-name' => 'logFile',
 					    '-cl_option' => '-l',
 					    '-cl_alias' => '--logFile',
 					    '-param' => 'yes',
 					    '-only_if' => 'not [interactive]'),
-				Option->new('-name' => 'plusLogStdout',
-					    '-cl_option' => '--plusLogStdout',
-					    '-only_if' => '[logFile]'),
 				Option->new('-name' => 'suppressTime',
 					    '-cl_option' => '--suppressTime'),
 				Option->new('-name' => 'maxFilelen',
@@ -405,15 +361,7 @@ my $CheckPar =
 				Option->new('-name' => 'genDeltaCacheConf',
 					    '-cl_option' => '--genDeltaCacheConf',
 		    '-only_if' => 'not [backupDir] and not [genBackupBaseTreeConf]',
-					    '-param' => 'yes'),
-# hidden options
-# used by storeBackupMount.pl
-				Option->new('-name' => 'writeToNamedPipe',
-					    '-cl_option' => '--writeToNamedPipe',
-					    '-param' => 'yes',
-					    '-hidden' => 'yes'),
-				Option->new('-name' => 'skipSync',
-					    '-cl_option' => '--skipSync')
+					    '-param' => 'yes')
 				]
 		    );
 
@@ -434,13 +382,8 @@ my $copyBackupOnly = $CheckPar->getOptWithoutPar('copyBackupOnly');
 my $dontCopyBackup = $CheckPar->getOptWithoutPar('dontCopyBackup');
 $archiveDurationDeltaCache = $CheckPar->getOptWithPar('archiveDurationDeltaCache');
 my $dontDelInDeltaCache = $CheckPar->getOptWithoutPar('dontDelInDeltaCache');
-my $createNewSeries = $CheckPar->getOptWithoutPar('createNewSeries');
 my $progressReport = $CheckPar->getOptWithPar('progressReport');
-my $noWarningDiffSeriesInBackupCopy =
-    $CheckPar->getOptWithoutPar('noWarningDiffSeriesInBackupCopy');
-my $maxHardLinks = $CheckPar->getOptWithPar('maxHardLinks');
 my $logFile = $CheckPar->getOptWithPar('logFile');
-my $plusLogStdout = $CheckPar->getOptWithoutPar('plusLogStdout');
 my $withTime = not $CheckPar->getOptWithoutPar('suppressTime');
 $withTime = $withTime ? 'yes' : 'no';
 my $maxFilelen = $CheckPar->getOptWithPar('maxFilelen');
@@ -450,9 +393,6 @@ my $compressWith = $CheckPar->getOptWithPar('compressWith');
 my $backupDir = $CheckPar->getOptWithPar('backupDir');
 my $genBackupBaseTreeConf = $CheckPar->getOptWithPar('genBackupBaseTreeConf');
 my $genDeltaCacheConf = $CheckPar->getOptWithPar('genDeltaCacheConf');
-# hidden options
-my $writeToNamedPipe = $CheckPar->getOptWithPar('writeToNamedPipe');
-my $skipSync = $CheckPar->getOptWithoutPar('skipSync');
 
 
 unless ($noCompress)
@@ -615,15 +555,13 @@ my ($prLogKind) = ['A:BEGIN',
 		   'P:PROGRESS',
 		   'S:STATISTIC',
 		   'D:DEBUG'];
-my $prLog1 = printLog->new('-kind' => $prLogKind,
-			   @par,
-			   '-withTime' => $withTime,
-			   '-maxFilelen' => $maxFilelen,
-			   '-noOfOldFiles' => $noOfOldFiles,
-			   '-saveLogs' => $saveLogs,
-			   '-compressWith' => $compressWith);
-
-my $prLog = printLogMultiple->new('-prLogs' => [$prLog1]);
+my $prLog = printLog->new('-kind' => $prLogKind,
+			  @par,
+			  '-withTime' => $withTime,
+			  '-maxFilelen' => $maxFilelen,
+			  '-noOfOldFiles' => $noOfOldFiles,
+			  '-saveLogs' => $saveLogs,
+			  '-compressWith' => $compressWith);
 $prLog->fork($req);
 
 if ($print)
@@ -632,49 +570,19 @@ if ($print)
     exit 0;
 }
 
-if ($plusLogStdout)
-{
-    my $p = printLog->new('-kind' => $prLogKind,
-			  '-filedescriptor', *STDOUT);
-    $prLog->add('-prLogs' => [$p]);
-}
-if ($writeToNamedPipe)
-{
-    my $pl = $prLog;
-    my $np = printLog->new('-kind' => $prLogKind,
-			   '-file' => $writeToNamedPipe,
-			   '-maxFilelen' => 0);
-    $prLog = printLogMultiple->new('-prLogs' => [$pl, $np]);
-}
-
 if ($interactive)
 {
     $verbose = 1;
     $debug = 1;
 }
 
-$main::IOCompressDirect = 0;
-eval "use IO::Compress::Bzip2 qw(bzip2)";
-if ($@)
-{
-    $prLog->print('-kind' => 'I',
-		  '-str' =>
-		  ["please install IO::Compress::Bzip2 from " .
-		   "CPAN for better performance"]);
-}
-else
-{
-    $main::IOCompressDirect = 1;
-}
-
-
 $prLog->print('-kind' => 'A',
 	      '-str' =>
 	      ["checking references and backup copying in <$backupDir>"]);
 $prLog->print('-kind' => 'V',
 	      '-str' => ["storeBackupUpdateBackup.pl, $main::STOREBACKUPVERSION"]);
 
-&::checkLockFile($lockFile, $prLog);
+::checkLockFile($lockFile, $prLog);
 
 exit 1
     unless &deleteOldBackupDirs::checkTimeScaleFormat('archiveDurationDeltaCache',
@@ -683,22 +591,12 @@ exit 1
 
 my (%seriesToCopy);   # $seriesToCopy{series}{backupCopyName}
 my $deltaCache = undef;
-my $backupType = 'none';
 if (-e "$backupDir/$baseTreeConf" and not $dontCopyBackup)
 {
 # read storeBackupBaseTree.conf in $backupDir
-    my ($backupTreeName, $seriesToDistribute);
+    my ($backupTreeName, $backupType, $seriesToDistribute);
     ($backupTreeName, $backupType, $seriesToDistribute, $deltaCache) =
-	&::readBackupDirBaseTreeConf("$backupDir/$baseTreeConf",
-				     &::absolutePath($backupDir), $prLog);
-
-#print "-1----------------=======------------\n";
-    # replace wildcards in replicated backup
-    my (@readSeries) = &::evalExceptionList_PlusMinus($seriesToDistribute,
-					    &::absolutePath($backupDir),
-				      "$backupTreeName series", 'series', 1,
-					    undef, 1, $prLog);
-#print "-1.1------readSeries=@readSeries\n";
+	&::readBackupDirBaseTreeConf("$backupDir/$baseTreeConf", $prLog);
 
 #print "backupTreeName = <$backupTreeName>\n";
 #print "backupType = <$backupType>\n";
@@ -721,63 +619,11 @@ if (-e "$backupDir/$baseTreeConf" and not $dontCopyBackup)
 
     if ($backupType eq 'copy')
     {
-#print "-2----------------=======------------\n";
-	# build hash with list of series in replication directory
-	my (%readSeries);
-#print "readSeries=<@readSeries>\n";
-	foreach my $r (@readSeries)
-	{
-#print "$r\n";
-	    $readSeries{$r} = 1;
-	}
-
+	$autorepairError = 0;
 	# read deltaCache.conf in $deltaCache
 	my $cscFile = "$deltaCache/$deltaCacheConf";
-	my (@bc) = &::readDeltaCacheConf($cscFile, $deltaCache, 1, $prLog);
 
-#print "-2.5----------------=======------------\n";
-	# generate list with existing series in Delta Cache
-	my (@listSeriesExistInDelta) = ();
-	foreach my $bc (@bc)
-	{
-#print "===> $bc[0][0] --------- $backupTreeName\n";
-	    if ($bc[0][0] eq $backupTreeName)
-	    {
-		(@listSeriesExistInDelta) = (@$bc[1..@$bc-1]);
-	    }
-#print "-3----------+Delta Cache Series++++++@listSeriesExistInDelta++\n";
-	}
-	# generate missing series directories in replication directory
-	# This has to be done 'on the fly' also when using wildcards in series names
-	my $createSeries = 0;
-	foreach my $d (@listSeriesExistInDelta)
-	{
-#print "3.5 -- <$d> -- ", (defined $readSeries{$d}), "\n";
-	    if ($createNewSeries and not defined $readSeries{$d})
-	    {
-#print "3.6-- <$backupDir/$d>\n";
-		exit 1
-		    unless &::makeDirPath("$backupDir/$d", $prLog);
-		$createSeries = 1;
-	    }
-	}
-#print "-4----------------=======------------\n";
-#print "-4.1------seriesToDistribute=@$seriesToDistribute\n";
-	if ($createSeries)
-	{
-	    # replace wildcards in replicated backup
-	    (@readSeries) = &::evalExceptionList_PlusMinus($seriesToDistribute,
-						    &::absolutePath($backupDir),
-						    "$backupTreeName series", 'series',
-						    1, undef, 1, $prLog);
-	}
-	$seriesToDistribute =\@readSeries;
-#print "-4.2------seriesToDistribute=@$seriesToDistribute\n";
-
-	$autorepairError = 0;
-#	# read deltaCache.conf in $deltaCache
-#	my $cscFile = "$deltaCache/$deltaCacheConf";
-#	my (@bc) = &::readDeltaCacheConf($cscFile, $deltaCache, 1, $prLog);
+	my (@bc) = &::readDeltaCacheConf($cscFile, $prLog);
 
 	# check consistency of backupCopy and deltaCache configuration
 	my $foundBackupTreeNameFlag = 0;
@@ -808,19 +654,18 @@ if (-e "$backupDir/$baseTreeConf" and not $dontCopyBackup)
 		}
 		foreach $s (@$seriesToDistribute)
 		{
-#print "---removing series <$s>\n";
 		    if (exists $s{$s})
 		    {
 			delete $s{$s};
 		    }
 		    else
 		    {
-			$prLog->print('-kind' => 'W',
+			$prLog->print('-kind' => 'E',
 				      '-str' =>
 				      ["$cscFile: series <$s> is missing in <" .
 				       $$bc[0] . ">, defined in " .
-				       "$backupDir/$baseTreeConf"])
-			    unless $noWarningDiffSeriesInBackupCopy;
+				       "$backupDir/$baseTreeConf"],
+				      '-exit' => 1);
 		    }
 
 		}
@@ -829,9 +674,7 @@ if (-e "$backupDir/$baseTreeConf" and not $dontCopyBackup)
 			      '-str' =>
 			      ["$backupDir/$baseTreeConf series <" .
 			       join('><', sort keys %s) . "> missing in <" .
-			       $$bc[0] . ">, defined in $cscFile",
-			       "use option --createNewSeries if you want " .
-			       "missing series to be created automatically"],
+			       $$bc[0] . ">, defined in $cscFile"],
 			      '-exit' => 1)
 		    if scalar keys %s;
 	    }
@@ -901,7 +744,7 @@ if (-e "$backupDir/$baseTreeConf" and not $dontCopyBackup)
 			      ["copying <$deltaCache/$s/$d> to " .
 			       "<$backupDir/$s>"]);
 		&::copyDir("$deltaCache/$s/$d" => "$backupDir/$s",
-			   "/tmp/stbuUpdateBackup-", $prLog, 0);
+			   "/tmp/stbuUpdateBackup-", $prLog);
 		open(FILE, '>>', "$deltaCache/$s/$d.copied") or
 		    $prLog->print('-kind' => 'E',
 				  '-str' =>
@@ -916,8 +759,6 @@ if (-e "$backupDir/$baseTreeConf" and not $dontCopyBackup)
     }
     elsif ($backupType eq 'master')
     {
-	$seriesToDistribute = \@readSeries;
-
 	my $s;
 	foreach $s (@$seriesToDistribute)
 	{
@@ -966,7 +807,7 @@ if (-e "$backupDir/$baseTreeConf" and not $dontCopyBackup)
 				  '-exit' => 1);
 		close(FILE);
 		&::copyDir("$backupDir/$s/$entry" => "$deltaCache/$s",
-			   "/tmp/stbuUpdateBackup-", $prLog, 0);
+			   "/tmp/stbuUpdateBackup-", $prLog);
 		unlink "$deltaCache/$s/$entry.notFinished";
 	    }
 	}
@@ -1095,8 +936,7 @@ while (((@lateLinkDirs) = $allLinks->getAllDirsWithLateLinks()) > 0)
 	$updateDirFlag = 1;
 	++$numberDirsToLinkCount;
 	::updateBackupDir($d, $noCompress, $progressReport, $prLog,
-			  $interactive, "$numberDirsToLinkCount/$numberDirsToLink",
-			  $backupType);
+			  $interactive, "$numberDirsToLinkCount/$numberDirsToLink");
 
 	if (-e "$backupDir/$baseTreeConf")
 	{
@@ -1113,15 +953,7 @@ while (((@lateLinkDirs) = $allLinks->getAllDirsWithLateLinks()) > 0)
 #print "<$d> ==> <$aktBackupDir> <$aktSeries> <$aktBackup>\n";
 
 	    my ($backupTreeName, $backupType, $seriesToDistribute, $deltaCache) =
-		&::readBackupDirBaseTreeConf("$backupDir/$baseTreeConf",
-					     &::absolutePath($backupDir), $prLog);
-	    # replace wildcards
-	    my (@readSeries) = &::evalExceptionList_PlusMinus($seriesToDistribute,
-						    &::absolutePath($backupDir),
-					    "$backupTreeName series", 'series', 0,
-						    undef, 1, $prLog);
-	    $seriesToDistribute =\@readSeries;
-
+		&::readBackupDirBaseTreeConf("$backupDir/$baseTreeConf", $prLog);
 	    my $found = 0;
 	    foreach my $s (@$seriesToDistribute)
 	    {
@@ -1392,8 +1224,8 @@ if (-e "$backupDir/$baseTreeConf" and $deltaCache)
 	my $dirs =
 	    allStoreBackupSeries->new('-rootDir' => "$cspb/$s",
 				      '-checkSumFile' => $checkSumFile,
-				      '-prLog' => $prLog);
-#				      '-absPath' => 0);
+				      '-prLog' => $prLog,
+				      '-absPath' => 0);
 	my (@dirs) = $dirs->getAllFinishedDirs();   # oldest first
 	my $d;
 	foreach $d (@dirs)
@@ -1479,12 +1311,9 @@ $prLog->print('-kind' => 'S',
 
 unlink $lockFile;
 
-unless ($skipSync)
-{
-    $prLog->print('-kind' => 'I',
-		  '-str' => ["syncing ..."]);
-    system "/bin/sync";
-}
+$prLog->print('-kind' => 'I',
+	      '-str' => ["syncing ..."]);
+system "/bin/sync";
 
 $prLog->print('-kind' => 'Z',
 	      '-str' =>
@@ -1493,16 +1322,6 @@ $prLog->print('-kind' => 'Z',
 exit 0;
 
 
-##################################################
-# package printLogMultiple needs this function
-sub cleanup
-{
-    my $signame = shift;
-    my $exit = (shift() || 1);
-
-    exit $exit;
-}
-
 
 ############################################################
 sub updateBackupDir
@@ -1513,7 +1332,6 @@ sub updateBackupDir
     my $prLog = shift;
     my $interactive = shift;
     my $count = shift;
-    my $backupType = shift;
 
     #
     # read compress from .md5CheckSum.info
@@ -1532,8 +1350,6 @@ sub updateBackupDir
     my ($compr, @comprPar) = @{$rcsf->getInfoWithPar('compress')};
     my $comprPostfix = $rcsf->getInfoWithPar('postfix');
 #print "compr = <$compr>, comprPar = <@comprPar>\n";
-    my $linkToRecent = $rcsf->getInfoWithPar('linkToRecent');
-#print "linkToRecent = <$linkToRecent>\n";
 
     #
     # set links and compress
@@ -1572,7 +1388,6 @@ sub updateBackupDir
 	next if $l =~ /^#/;
 	chomp $l;
 	my ($what, $md5) = split(/\s+/, $l, 2);
-#print "what = $what\n";
 
 	if ($what eq 'dir')
 	{
@@ -1637,67 +1452,34 @@ sub updateBackupDir
 	    $file = "$dir/$file";        # file to compress
 	    my $st = (stat($file))[7];
 	    $oldSize += $st if defined $st;
-	    $noCompressedFiles++;
-
-	    if ($main::IOCompressDirect and
-		$compr eq 'bzip2')
+	    my ($old, $new) =
+		$parForkProc->add_block('-exec' => $compr,
+					'-param' => \@comprPar,
+					'-outRandom' => '/tmp/bzip2-',
+					'-stdin' => $file,
+					'-stdout' => "$file$comprPostfix",
+					'-delStdout' => 'no',
+					'-info' => $file);
+	    if ($old)
 	    {
-		local *FILEIN;
-		sysopen(FILEIN, $file, O_RDONLY) or
-		    $prLog->print('-kind' => 'E',
-				  '-str' =>
-				  ["cannot open <$file> for compression"]);
-		my $bz = new IO::Compress::Bzip2("$file$comprPostfix",
-						 BlockSize100K => 9);
-		my $buffer;
-		while (sysread(FILEIN, $buffer, 1025))
-		{
-		    unless ($bz->syswrite($buffer))
-		    {
-			$prLog->print('-kind' => 'E',
-				      '-str' =>
-				      ["writing to <$file$comprPostfix> failed"]);
-		    }
-		}
-		$bz->flush();
-		$bz->eof();
-		close(FILEIN);
+		$noCompressedFiles++;
+		$prLog->print('-kind' => 'S',
+			      '-str' => ["compressed $noCompressedFiles files"])
+		    if ($progressReport and
+			$noCompressedFiles % $progressReport == 0);
 
-		$newSize += (stat("$file$comprPostfix"))[7];
+		my $f = $old->get('-what' => 'info');
+		&::waitForFile("$f$comprPostfix");
+		$newSize += (stat("$f$comprPostfix"))[7];
+		my $out = $old->getSTDERR();
 		$prLog->print('-kind' => 'E',
-			      '-str' => ["cannot delete <$file>"])
-		    if (unlink $file) != 1;
+			      '-str' => ["STDERR of <$compr @comprPar " .
+					 "<$f >$f$comprPostfix>:", @$out])
+		    if (@$out > 0);
+		$prLog->print('-kind' => 'E',
+			      '-str' => ["cannot delete <$f>"])
+		    if (unlink $f) != 1;
 	    }
-	    else
-	    {
-		my ($old, $new) =
-		    $parForkProc->add_block('-exec' => $compr,
-					    '-param' => \@comprPar,
-					    '-outRandom' => '/tmp/bzip2-',
-					    '-stdin' => $file,
-					    '-stdout' => "$file$comprPostfix",
-					    '-delStdout' => 'no',
-					    '-info' => $file);
-		if ($old)
-		{
-		    my $f = $old->get('-what' => 'info');
-		    &::waitForFile("$f$comprPostfix");
-		    my $out = $old->getSTDERR();
-		    $prLog->print('-kind' => 'E',
-				  '-str' => ["STDERR of <$compr @comprPar " .
-					     "<$f >$f$comprPostfix>:", @$out])
-			if (@$out > 0);
-		    $newSize += (stat("$f$comprPostfix"))[7];
-		    $prLog->print('-kind' => 'E',
-				  '-str' => ["cannot delete <$f>"])
-			if (unlink $f) != 1;
-		}
-	    }
-	    $prLog->print('-kind' => 'S',
-			  '-str' =>
-			  ["compressed $noCompressedFiles files"])
-		if ($progressReport and
-		    $noCompressedFiles % $progressReport == 0);
 	}
 	else
 	{
@@ -1735,49 +1517,13 @@ sub updateBackupDir
 	    if (unlink $f) != 1;
     }
 
-if ($backupType eq 'copy' and $linkToRecent)
-{
-    my ($_d, $link) = &::splitFileDir($dir);
-#print "_d = <$_d>, link = <$link>\n";
-    if (-l "$_d/$linkToRecent")
-    {
-	unlink "$_d/$linkToRecent";
-
-	$prLog->print('-kind' => 'W',
-		      '-str' => ["cannot create symlink linkToRecent " .
-				 "<$linkToRecent>"])
-	    unless symlink $link, "$_d/$linkToRecent";
-	++$noSymLink;
-#print "1 symlink $link, _d/$linkToRecent\n";
-    }
-    elsif (-e "$_d/$linkToRecent")
-    {
-	$prLog->print('-kind' => 'W',
-		      '-str' => ["cannot delete <$linkToRecent> " .
-				 "(option linkToRecent): " .
-				 "is not a symbolic link " .
-				 "or no permissons"]);
-    }
-    else    # does not exist, create a new one
-    {
-	$prLog->print('-kind' => 'W',
-		      '-str' => ["cannot create symlink linkToRecent " .
-				 "<$linkToRecent>"])
-	    unless symlink $link, "$_d/$linkToRecent";
-	++$noSymLink;
-#print "2 symlink $link, _d/$linkToRecent\n";
-    }
-}
-
-    my $percent = $oldSize ? $newSize / $oldSize * 100 : 0;
     $prLog->print('-kind' => 'S',
 		  '-str' => ["created $noMkdir directories",
 			     "created $noSymLink symbolic links",
 			     "compressed $noCompressedFiles files",
 			     "used " . (&::humanReadable($newSize))[0] .
 			     " instead of " . (&::humanReadable($oldSize))[0] .
-			     " ($newSize <- $oldSize ; " .
-			     (sprintf "%.1f", $percent) . "%)"]);
+			     " ($newSize <- $oldSize)"]);
 
     #
     # set hard links
@@ -1832,13 +1578,7 @@ if ($backupType eq 'copy' and $linkToRecent)
 	    $newLink =~ s/\0/\n/og;
 	    $newLink = "$dir/$newLink";
 	    $existingFile = $md5ToFile{$md5} if exists $md5ToFile{$md5};
-	    my $hl = -1;
-	    if ($maxHardLinks > 0)
-	    {
-		$hl = (stat($existingFile))[3];
-print "$existingFile: $hl hardlinks ($maxHardLinks)\n";
-	    }
-	    if ($hl < $maxHardLinks and link $existingFile, $newLink)
+	    if (link $existingFile, $newLink)
 	    {
 		$noHardLinks++;
 		$prLog->print('-kind' => 'S',
@@ -1848,7 +1588,7 @@ print "$existingFile: $hl hardlinks ($maxHardLinks)\n";
 	    else
 	    {
 		# copy file
-                unless (&::copyFile("$existingFile", "$newLink", $prLog))
+                unless (::copyFile("$existingFile", "$newLink"))
                 {
                     $prLog->print('-kind' => 'E',
                                   '-str' => ["could not link/copy " .
@@ -1889,13 +1629,7 @@ print "$existingFile: $hl hardlinks ($maxHardLinks)\n";
 	    chomp $newLink;
 	    $newLink =~ s/\0/\n/og;
 	    $newLink = "$dir/$newLink";
-	    my $hl = -1;
-	    if ($maxHardLinks  > 0)
-	    {
-		$hl = (lstat($existingFile))[3];
-#print "$existingFile: $hl hardlinks on symlinks ($maxHardLinks)\n";
-	    }
-	    if ($hl < $maxHardLinks and link $existingFile, $newLink)
+	    if (link $existingFile, $newLink)
 	    {
 		$noHardLinks++;
 		$prLog->print('-kind' => 'S',
@@ -1933,8 +1667,7 @@ print "$existingFile: $hl hardlinks ($maxHardLinks)\n";
 	    $newLink =~ s/\0/\n/og;
 
 	    $noHardLinks +=
-		&::hardLinkDir($existingFile, $newLink, '\A\d.*',
-			       undef, undef, undef, $prLog, $maxHardLinks);
+		&::hardLinkDir($existingFile, $newLink, '\A\d.*', $prLog);
 
 	    if ($withBlockedFiles)
 	    {
@@ -2013,11 +1746,13 @@ print "$existingFile: $hl hardlinks ($maxHardLinks)\n";
     #
     my $preservePerms =
 	$rcsf->getInfoWithPar('preservePerms') eq 'no' ? 0 : 1;
+#	(($$meta{'preservePerms'})->[0] eq 'no') ? 0 : 1;
     $pr = $progressReport * 2000;
     if ($preservePerms)
     {
 	$prLog->print('-kind' => 'I',
 		      '-str' => ["phase 3: setting file permissions"]);
+#	my $comprPostfix = ($$meta{'postfix'})->[0];
 	my $comprPostfix = $rcsf->getInfoWithPar('postfix');
 
 	my $noFiles = 0;
@@ -2036,7 +1771,7 @@ print "$existingFile: $hl hardlinks ($maxHardLinks)\n";
 	    if (not -l $file and not -e $file)
 	    {
 		$prLog->print('-kind' => 'E',
-			      '-str' => ["cannot access <$file>"]);
+			      '-str' => ["cannot acces <$file>"]);
 		next;
 	    }
 	    $noFiles++;
@@ -2050,29 +1785,6 @@ print "$existingFile: $hl hardlinks ($maxHardLinks)\n";
 	    chown $uid, $gid, $file;
 	    if ($compr eq 'b')         # block file
 	    {
-		local *BFDIR;
-		opendir(BFDIR, $file) or
-		    $prLog->print('-kind' => 'E',
-				  '-str' =>
-				  ["cannot opendir <$file> to set permissions"],
-				  '-add' => [__FILE__, __LINE__]);
-		my $bfentry;
-		while ($bfentry = readdir BFDIR)
-		{
-		    if ($bfentry =~ /\A\.md5BlockCheckSums/)
-		    {
-			chmod 0644, "$file/$bfentry";
-		    }
-		    else
-		    {
-			utime $atime, $mtime, "$file/$bfentry";
-			chown $uid, $gid, "$file/$bfentry";
-			chmod $mode, "$file/$bfentry";
-		    }
-		    $noFiles++;
-		}
-		closedir(BFDIR);
-
 		$mode &= 0777;    # strip special permissions
 		$mode |= 0111;    # add directory permissions
 	    }
@@ -2127,7 +1839,7 @@ print "$existingFile: $hl hardlinks ($maxHardLinks)\n";
 		unless (-e $file)
 		{
 		    $prLog->print('-kind' => 'E',
-				  '-str' => ["cannot access <$file>"]);
+				  '-str' => ["cannot acces <$file>"]);
 		    next;
 		}
 		chown $uid, $gid, $file;
