@@ -1,7 +1,7 @@
 #! /usr/bin/env perl
 
 #
-#   Copyright (C) Heinz-Josef Claes (2002-2020)
+#   Copyright (C) Heinz-Josef Claes (2002-2012)
 #                 hjclaes@web.de
 #   
 #   This program is free software: you can redistribute it and/or modify
@@ -91,8 +91,6 @@ require 'checkParam2.pl';
 require 'version.pl';
 require 'humanRead.pl';
 require 'storeBackupLib.pl';
-require 'fileDir.pl';
-
 
 =head1 NAME
 
@@ -121,12 +119,14 @@ storeBackup_du.pl - evaluates the disk usage in one or more backup directories.
 
 =head1 COPYRIGHT
 
-Copyright (c) 2002-2020 by Heinz-Josef Claes (see README).
+Copyright (c) 2002-2012 by Heinz-Josef Claes (see README)
 Published under the GNU General Public License v3 or any later version
 
 =cut
 
-my $Help = &::getPod2Text($0);
+my $Help = join('', grep(!/^\s*$/, `pod2text $0`));
+$Help = "cannot find pod2text, see documentation for details\n"
+    unless $Help;
 
 die "$Help" unless @ARGV;
 
