@@ -1,7 +1,7 @@
 # -*- perl -*-
 
 #
-#   Copyright (C) Heinz-Josef Claes (2002-2020)
+#   Copyright (C) Heinz-Josef Claes (2002-2012)
 #                 hjclaes@web.de
 #   
 #   This program is free software: you can redistribute it and/or modify
@@ -53,9 +53,6 @@
 #my $configFile = $CheckPar->getOptWithPar('confFile');
 #my $verbose = $CheckPar->getOptWithoutPar('verbose');
 #$CheckPar->print();
-#my (@list) = $CheckPar->getListPar();
-#my numberListPar = $CheckPar->getNoListPar();
-#my (@list) = $CheckPar->getOptOrder();
 #
 ######################################################################
 # Options of Option::new
@@ -231,8 +228,6 @@
 use strict;
 
 require 'checkObjPar.pl';
-require 'prLog.pl';
-
 ######################################################################
 # Speicherung s"amtlicher Informationen "uber *einen* Parameter
 package Option;
@@ -314,6 +309,7 @@ sub new
 
     die "-multiple must be 'yes' or 'no' in option <", $params{'-name'}, ">"
 	unless $params{'-multiple'} =~ /\Ayes\Z|\Ano\Z/;
+
     die "-priority must be 'cl' or 'cf' in option <", $params{'-name'}, ">"
 	unless $params{'-priority'} =~ /\Acl\Z|\Acf\Z/;
 
@@ -361,8 +357,7 @@ sub new
     # Defaultwerte f"ur Parameter setzen
     my (%params) = ('-file' => undef,
 		    '-replaceEnvVar' => 'yes',
-		    '-ignoreLeadingWhiteSpace' => undef,
-		    '-prLog' => undef
+		    '-ignoreLeadingWhiteSpace' => undef
 	);
 
     &::checkObjectParams(\%params, \@_, 'ConfigFile::new',
@@ -370,13 +365,8 @@ sub new
     &::setParamsDirect($self, \%params);
     bless $self, $class;
 
-    my $prLog = $self->{'prLog'};
-
-    unless ($self->{'replaceEnvVar'} =~ /\Ayes\Z|\Ano\Z/)
-    {
-	my $err = "replaceEnvVar must be 'yes' or 'no' in ConfigFile::new";
-	&ConfigFile::printDie($err, $prLog);
-    }
+    die "replaceEnvVar must be 'yes' or 'no' in ConfigFile::new"
+	unless $self->{'replaceEnvVar'} =~ /\Ayes\Z|\Ano\Z/;
     my $ignoreLeadingWhiteSpace = $self->{'ignoreLeadingWhiteSpace'};
 
     # read config file
@@ -385,20 +375,16 @@ sub new
     if ($file =~ /\.bz2\Z/)
     {
 	open(FILE, "bzip2 -d < \'$file\' |") or
-	    &ConfigFile::printDie("cannot open configuration file <$file>",
-				  $prLog);
+	    die "cannot open configuration file <$file>";
     }
     elsif ($file =~ /\.gz\Z/)
     {
 	open(FILE, "gzip -d < \'$file\' |") or
-	    &ConfigFile::printDie("cannot open configuration file <$file>",
-				  $prLog);
+	    die "cannot open configuration file <$file>";
     }
     else
     {
-	open(FILE, $file) or
-	    &ConfigFile::printDie("cannot open configuration file <$file>",
-				  $prLog);
+	open(FILE, $file) or die "cannot open configuration file <$file>";
     }
     my (@configFile) = <FILE>;
     chomp @configFile;
@@ -438,10 +424,8 @@ sub new
 	    }
 	    else
 	    {
-		&ConfigFile::printDie(
-		     "cannot identify line $i in file $file:\n<" .
-		     $configFile[$i-1] . ">",
-		     $prLog);
+		die "cannot identify line $i in file $file:\n<",
+		$configFile[$i-1], ">\n";
 	    }
 	}
     }
@@ -453,8 +437,7 @@ sub new
 	$l = $keys{$actKey}{'line'};
 	my $v = splitQuotedLine($l, "in configuration file at line " .
 				$keys{$actKey}{'lineno'},
-				$self->{'replaceEnvVar'} eq 'no',
-				$prLog);
+				$self->{'replaceEnvVar'} eq 'no');
 	if (@$v)
 	{
 	    $keys{$actKey}{'parts'} = $v;
@@ -468,40 +451,15 @@ sub new
     return $self;
 }
 
-########################################
-sub printDie
-{
-    my $err = shift;
-    my $prLog = shift;
-
-    if (defined($prLog))
-    {
-	$prLog->print('-kind' => 'E',
-		      '-str' => [$err],
-		      '-exit' => 1);
-    }
-    else
-    {
-	die $err;
-    }
-}
-
 ########################################
 sub splitQuotedLine
 {
     my $l = shift;
     my $errorPart = shift;   # where this happens, 'in file at ...'
     my $doNotReplaceEnvVar = shift;   # 1 or undef
-    my $prLog = shift;       # pointer to object or <undef>
 
     $doNotReplaceEnvVar = 0 unless defined $doNotReplaceEnvVar;
 
-#print "splitQuotedLine: l = <$l>\n";
-#print "splitQuotedLine: errorPart = <$errorPart>\n";
-#print "splitQuotedLine: doNotReplaceEnvVar = <$doNotReplaceEnvVar>\n";
-#print "splitQuotedLine: prLog = <$prLog>\n";
-
-
     # masking of special characters
     my $dollar = "\001";  # mask for \$
     my $ob = "\002";      # open bracket: mask for \{
@@ -513,7 +471,7 @@ sub splitQuotedLine
     $l =~ s/\\\{/$ob/g;    # replace \{ with $ob
     $l =~ s/\\\}/$cb/g;    # replace \} with $cb
     $l =~ s/\\\'/$sq/g;    # replace \' with $sq
-    $l =~ s/\\\"/$dq/g;    # replace \" with $dq
+    $l =~ s/\\\"/$dq/g;    # replace \" with $sq
 
     my (@l);
 #print "l = <$l>, doNotReplaceEnvVar = <$doNotReplaceEnvVar>\n";
@@ -527,7 +485,7 @@ sub splitQuotedLine
 	if ($sQuote == -1 and $dQuote == -1)   # no quotes
 	{
 	    push @l, replaceEnvironmentVars($doNotReplaceEnvVar,
-					    $errorPart, $prLog,
+					    $errorPart,
 					    split(/\s+/, $l));
 	    $l = '';
 	}
@@ -538,7 +496,7 @@ sub splitQuotedLine
 	    if ($l =~ /\A(.*?)\'(.*?)\'(.*)\Z/)
 	    {
 		push @l, replaceEnvironmentVars($doNotReplaceEnvVar,
-						$errorPart, $prLog,
+						$errorPart,
 						split(/\s+/, $1));
 		push @l, $2;
 		$l = $3;
@@ -546,8 +504,7 @@ sub splitQuotedLine
 	    }
 	    else
 	    {
-		&ConfigFile::printDie("missing \' $errorPart:\n<$l>",
-				      $prLog);
+		die "missing \' $errorPart:\n<$l>\n";
 	    }
 	}
 	else              # double quote
@@ -556,17 +513,16 @@ sub splitQuotedLine
 	    if ($l =~ /\A(.*?)\"(.*?)\"(.*)\Z/)
 	    {
 		push @l, replaceEnvironmentVars($doNotReplaceEnvVar,
-						$errorPart, $prLog,
+						$errorPart,
 						split(/\s+/, $1));
 		push @l, replaceEnvironmentVars($doNotReplaceEnvVar,
-						$errorPart, $prLog, $2);
+						$errorPart, $2);
 #print "\t<", join('> <', @l), "> + <$l>\n";
 		$l = $3;
 	    }
 	    else
 	    {
-		&ConfigFile::printDie("missing \" $errorPart:\n<$l>",
-				      $prLog);
+		die "missing \" $errorPart:\n<$l>\n";
 	    }
 	}
     }
@@ -589,14 +545,7 @@ sub splitQuotedLine
 ########################################
 sub replaceEnvironmentVars
 {
-    my ($doNotReplaceEnvVar, $errorPart, $prLog, @lines) = @_;
-
-#print "replaceEnvironmentVars: doNotReplaceEnvVar = <$doNotReplaceEnvVar>\n";
-#print "replaceEnvironmentVars: errorPart = <$errorPart>\n";
-#print "replaceEnvironmentVars: prLog = <$prLog>\n";
-#print "replaceEnvironmentVars: lines = <@lines>\n";
-
-    # prLog must be object or <undef>
+    my ($doNotReplaceEnvVar, $errorPart, @lines) = @_;
 
     return (@lines) if $doNotReplaceEnvVar;
 
@@ -625,9 +574,8 @@ sub replaceEnvironmentVars
 		    $env = $1;
 		}
 
-		&ConfigFile::printDie("environment variable \$$env not set\n" .
-		"please set \$$env before calling this program $errorPart",
-				      $prLog)
+		die "environment variable \$$env not set\n",
+		"please set \$$env before calling this program $errorPart"
 		    unless $ENV{$env};
 
 		$l =~ s/\$\{?$env\}?/$ENV{$env}/;
@@ -662,8 +610,7 @@ sub new
 		    '-allowLists' => 'no',
 		    '-listMapping' => undef,
 		    '-replaceEnvVar' => 'yes',
-		    '-ignoreLeadingWhiteSpace' => undef,
-		    '-prLog' => undef);
+		    '-ignoreLeadingWhiteSpace' => undef);
 
     $params{'-allowLists'} = 'yes'
 	if defined $params{'-listMapping'};
@@ -673,48 +620,31 @@ sub new
     $self->{'paramList'} = \%params;    # Parameter an Objekt binden
     $self->{'listMapping'} = $params{'-listMapping'};
 
-    my $prLog = $self->{'paramList'}{'-prLog'};
     # Hash mit '-cl_option' und '-cl_alias' f"ur schnellen Zugriff auf Option
     # Hash mit '-cf_key' f"ur schnellen Zugriff auf Option
     my (%option, %key, %name, %n, $o);
     foreach $o (@{$self->{'paramList'}{'-list'}})
     {
 	my $n = $o->get('-name');
-	if (exists $n{$n})
-	{
-	    my $err = "option name <$n> used twice (1)";
-	    &ConfigFile::printDie($err, $prLog);
-	}
+	die "option name <$n> used twice" if exists $n{$n};
 	$n{$n} = 1;
 	my $opt = undef;
 	if ($opt = $o->get('-cl_option'))
 	{
-	    if (exists $option{$opt})
-	    {
-		my $err = "cl_option <$opt> used twice! (2)";
-		&ConfigFile::printDie($err, $prLog);
-	    }
+	    die "cl_option <$opt> used twice!" if exists $option{$opt};
 	    $option{$opt} = $o;
 	    my $name = $o->get('-name');
 	    $name{$n} = $o;
 	}
 	if ($opt = $o->get('-cl_alias'))
 	{
-	    if (exists $option{$opt})
-	    {
-		my $err = "cl_option <$opt> used twice! (3)";
-		&ConfigFile::printDie($err, $prLog);
-	    }
+	    die "cl_option <$opt> used twice!" if exists $option{$opt};
 	    $option{$opt} = $o;
 	    $name{$n} = $o;
 	}
 	if ($opt = $o->get('-cf_key'))
 	{
-	    if (exists $key{$opt})
-	    {
-		my $err = "cf_key <$opt> used twice!";
-		&ConfigFile::printDie($err, $prLog);
-	    }
+	    die "cf_key <$opt> used twice!" if exists $key{$opt};
 	    $key{$opt} = $o;
 	    $name{$n} = $o;
 	}
@@ -744,8 +674,6 @@ sub check
 		    '-help' => ['<noHelp>'],
 		    '-ignoreAdditionalKeys' => undef);
 
-    my $prLog = $self->{'paramList'}{'-prLog'};
-
     my $replaceEnvVar =
 	$self->{'paramList'}{'-replaceEnvVar'};
     my (%hash) = @_;    # Parameter in Hash kopieren
@@ -763,12 +691,9 @@ sub check
 	}
     }
     my ($Help) = $params{'-help'};
-    if (keys %hash > 0)
-    {
-	my $err = "undefined params <" . join('><' . keys %hash) .
-	    "> in CheckParam::check";
-	&ConfigFile::printDie($err, $prLog);
-    }
+    die "undefined params <", join('><', keys %hash),
+    "> in CheckParam::check\n"
+	if (keys %hash > 0);
 
     # Die gesetzten Optionen erst einmal auf Parameter analysieren
     my $op = $self->{'optionsPointer'};
@@ -776,22 +701,17 @@ sub check
     if (defined $self->{'paramList'}{'-configFile'})
     {
 	$configFileParam = $self->{'paramList'}{'-configFile'};
-	unless (exists $op->{$configFileParam})
-	{
-	    my $err =
-		"CheckParam::configFile option <$configFileParam> does not exist";
-	    &ConfigFile::printDie($err, $prLog);
-	}
+	die "CheckParam::configFile option <$configFileParam> does not exist"
+	    unless exists $op->{$configFileParam};
     }
 
     my ($arg, @parList, $next, $aktOpt, %optWithPar,
-	@optOrder, %optWithoutPar, %unset, $i);
+	%optWithoutPar, %unset, $i);
 
     # Ergebnisse merken
     $self->{'Erg'}{'withPar'} = \%optWithPar;
     $self->{'Erg'}{'withoutPar'} = \%optWithoutPar;
     $self->{'Erg'}{'listPar'} = \@parList;
-    $self->{'Erg'}{'optOrder'} = \@optOrder;
 
     $next = 'unknown';
     my $i;
@@ -813,21 +733,15 @@ sub check
 	}
 	if ($arg eq '--')   # n"achster Parameter ist 'list' - Parameter
 	{
-	    if ($i + 1 >= @{$params{'-argv'}})
-	    {
-		my $err = "missing list parameter after '--'";
-		&ConfigFile::printDie($err, $prLog);
-	    }
+	    die "missing list parameter after '--'"
+		if $i + 1 >= @{$params{'-argv'}};
 	    $next = 'list';
 	    next;
 	}
 	if ($arg eq '--unset')
 	{
-	    if ($i + 1 >= @{$params{'-argv'}})
-	    {
-		my $err = "missing list parameter after '--unset'";
-		&ConfigFile::printDie($err, $prLog);
-	    }
+	    die "missing list parameter after '--unset'"
+		if $i + 1 >= @{$params{'-argv'}};
 	    $next = 'unset';
 	    next;
 	}
@@ -837,52 +751,39 @@ sub check
 	    $arg = $o->get('-cl_option');
 	    $o->set('-used' => 'yes');
 	    my $name = $o->get('-name');
-	    push @optOrder, $name;
 
 	    if ($o->get('-param') eq 'yes')
 	    {
 		$optWithPar{$name}{'object'} = $o;
-		if (++$i >= @{$params{'-argv'}})
-		{
-		    my $err = "missing param for option <$arg>\n$Help";
-		    &ConfigFile::printDie($err, $prLog);
-		}
+		die "missing param for option <$arg>\n$Help"
+		    if (++$i >= @{$params{'-argv'}});
 		if ($o->get('-multiple') eq 'yes')
 		{
-			if ($arg eq $configFileParam)
-			{
-			    my $err =
-				"Parameter $arg is used for setting the configuration" .
-				" file. It cannot be used with -multiple => yes";
-			    &ConfigFile::printDie($err, $prLog);
-			}
+		    die "Parameter $arg is used for setting the configuration" .
+			" file. It cannot be used with -multiple => yes"
+			if $arg eq $configFileParam;
 		    my $l = $params{'-argv'}[$i];
 		    if ($l eq '--')
 		    {
-			if (++$i >= @{$params{'-argv'}})
-			{
-			    my $err = "missing param for option <$arg>\n$Help";
-			    &ConfigFile::printDie($err, $prLog);
-			}
+			die "missing param for option <$arg>\n$Help"
+			    if (++$i >= @{$params{'-argv'}});
 			$l = $params{'-argv'}[$i];
 			push @{$optWithPar{$name}{'value'}},
 			@{ConfigFile::splitQuotedLine($l, "at <$arg>",
-			  $replaceEnvVar eq 'no', $prLog)};
+			  $replaceEnvVar eq 'no')};
 		    }
 		    else
 		    {
 			if ($o->get('-quoteEval') eq 'yes')
 			{
-			    if (defined $optWithPar{$name}{'value'})
-			    {
-				my $err = "cannot use $arg multiple times\n$Help";
-				&ConfigFile::printDie($err, $prLog);
-			    }
+			    die "cannot use $arg multiple times\n$Help",
+				if defined $optWithPar{$name}{'value'};
+
 			    $l = $params{'-argv'}[$i];
 			    $optWithPar{$name}{'value'} = ();
 			    push @{$optWithPar{$name}{'value'}},
 			    @{ConfigFile::splitQuotedLine($l, "at <$arg>",
-			      $replaceEnvVar eq 'no', $prLog)};
+			      $replaceEnvVar eq 'no')};
 			}
 			else
 			{
@@ -894,11 +795,10 @@ sub check
 		{
 		    if (defined $optWithPar{$name}{'value'})
 		    {
-			my $err = "parameter $arg defined multiple times with\n<" .
-			    $optWithPar{$name}{'value'} . "> <" . $params{'-argv'}[$i] .
-			    ">\nit is not possible to have multiple instances" .
+			die "parameter $arg defined multiple times with\n<",
+			$optWithPar{$name}{'value'}, "> <", $params{'-argv'}[$i],
+			">\nit is not possible to have multiple instances" .
 			    " of this parameter\n$Help";
-			&ConfigFile::printDie($err, $prLog);
 		    }
 		    else
 		    {
@@ -917,11 +817,7 @@ sub check
 	}
 	else      # Listenparameter
 	{
-	    if ($arg =~ /^-/)
-	    {
-		my $err = "unknown parameter <$arg>\n$Help";
-		&ConfigFile::printDie($err, $prLog);
-	    }
+	    die "unknown parameter <$arg>\n$Help" if ($arg =~ /^-/);
 	    push @parList, $arg;
 	    next;
 	}
@@ -935,7 +831,7 @@ sub check
     if (0)
     {
 	my ($k);
-	print "(1) Ausgabe der gefundenen Command Line Optionen\n";
+	print "Ausgabe der gefundenen Command Line Optionen\n";
 	print "\tOptionen mit Parameter:\n";
 	foreach $k (sort keys %optWithPar)
 	{
@@ -977,8 +873,7 @@ sub check
 	my $cf = ConfigFile->new('-file' => $configFile,
 				 '-replaceEnvVar' => $replaceEnvVar,
 				 '-ignoreLeadingWhiteSpace' =>
-				 $self->{'paramList'}{'-ignoreLeadingWhiteSpace'},
-				 '-prLog' => $prLog
+				 $self->{'paramList'}{'-ignoreLeadingWhiteSpace'}
 	    );
 
 	my $kp_cf_file = $cf->getKeysPointer();
@@ -992,8 +887,8 @@ sub check
 		my $kp = $kp_cf_file->{$fileKey};
 #print "++++++++++++\n-1- key: <$fileKey>\n";
 #print "-2- lineno: ", $kp->{'lineno'}, "\n";
-#print "-3- parts: <",              # value in config file
-#    join("><", @{$kp->{'parts'}}), ">\n";
+#print "-3- parts: <",
+#join("><", @{$kp->{'parts'}}), ">\n";
 
 		my $k = $kp_definition->{$fileKey};
 		my $name = $k->get('-name');
@@ -1002,34 +897,28 @@ sub check
 
 #print "-5- -cf_key = ", $k->get('-cf_key'), "\n";
 #print "-5- -name = ", $name, "\n";
-#print "-5- -priority = ", $k->get('-priority'), "\n";
 #print "-5- -multiple = ", $k->get('-multiple'), "\n";
 #print "-6- -cf_noOptSet = <",
-#    join("><", @{$k->get('-cf_noOptSet')}), ">\n"
-#    if defined $k->get('-cf_noOptSet');
+#join("><", @{$k->get('-cf_noOptSet')}), ">\n"
+#  if defined $k->get('-cf_noOptSet');
 
 		if (@{$kp->{'parts'}} > 1 and $k->get('-multiple') eq 'no')
 		{
-		    my $err = "configuration file $configFile, line " .
-			$kp->{'lineno'} .
-			": key <$fileKey> must have only one parameter\n$Help";
-		    &ConfigFile::printDie($err, $prLog);
+		    die "configuration file $configFile, line ",
+		    $kp->{'lineno'},
+		    ": key <$fileKey> must have only one parameter\n$Help";
 		}
+
+		next if $k->get('-priority') eq 'cl' and
+		    $k->get('-used') eq 'yes';
+
 		$k->set('-used' => 'yes');
 
 		if ($k->get('-multiple') eq 'yes')
 		{
 		    my $val = $kp->{'parts'};
 		    $val = undef if @$val == 1 and $$val[0] eq '[[undef]]';
-#print "ELSE(m) $name val=<$val>,  optWithPar = ", $optWithPar{$name}{'value'}, "\n";
-#print "\tnicht definert\n" unless defined($optWithPar{$name}{'value'});
-#print "\tdefinert\n" if defined($optWithPar{$name}{'value'});
-		    if (not defined($optWithPar{$name}{'value'}) or
-			$k->get('-priority') eq 'cf')
-		    {
-			($optWithPar{$name}{'value'}) = $val;
-		    }
-
+		    $optWithPar{$name}{'value'} = $val;
 		}
 		else           # -muliple eq 'no'
 		{
@@ -1038,13 +927,11 @@ sub check
 			my ($yes, $no) = (@{$k->get('-cf_noOptSet')});
 			my ($val) = (@{$kp->{'parts'}});
 			$val = $no unless $val;
-			if ($val ne $yes and $val ne $no)
-			{
-			    my $err ="configuration file $configFile, line " .
-				$kp->{'lineno'} .
-				": value for key <$fileKey> is <$val>, must be <$yes> or <$no>";
-			    &ConfigFile::printDie($err, $prLog);
-			}
+			die "configuration file $configFile, line ",
+			$kp->{'lineno'},
+			": value for key <$fileKey> is <$val>, must be <$yes> or <$no>"
+			    if $val ne $yes and $val ne $no;
+
 			$optWithoutPar{$name} =
 			    ($val eq $yes) ? 1 : undef;
 		    }
@@ -1052,26 +939,16 @@ sub check
 		    {
 			my $val = $kp->{'parts'}[0];
 			$val = undef if $val eq '[[undef]]';
-#print "ELSE(s) $name val=<$val>,  optWithPar = ", $optWithPar{$name}{'value'}, "\n";
-#print "\tnicht definert\n" unless defined($optWithPar{$name}{'value'});
-#print "\tdefinert\n" if defined($optWithPar{$name}{'value'});
-			if (not defined($optWithPar{$name}{'value'}) or
-			    $k->get('-priority') eq 'cf')
-			{
-			    ($optWithPar{$name}{'value'}) = $val;
-			}
+			($optWithPar{$name}{'value'}) = $val;
 		    }
 		}
 	    }
 	    else
 	    {
-		unless ($params{'-ignoreAdditionalKeys'})
-		{
-		    my $err = "configuration file $configFile, line " .
-			$kp_cf_file->{$fileKey}{'lineno'} .
-			": undefined key <$fileKey>\n$Help";
-		    &ConfigFile::printDie($err, $prLog);
-		}
+		die "configuration file $configFile, line ",
+		$kp_cf_file->{$fileKey}{'lineno'},
+		": undefined key <$fileKey>\n$Help"
+		    unless $params{'-ignoreAdditionalKeys'};
 	    }
 	}
 
@@ -1080,7 +957,7 @@ sub check
     if (0)
     {
 	my ($k);
-	print "\t(2) Optionen aus Config File + Command Line mit Parameter:\n";
+	print "\tOptionen aus Command Line mit Parameter:\n";
 	foreach $k (sort keys %optWithPar)
 	{
 	    if (ref($optWithPar{$k}{'value'}) eq 'ARRAY')
@@ -1116,23 +993,17 @@ sub check
     }
 
     # Überprüfen, ob List-Parameter erlaubt sind
-    if (@parList > 0 and $self->{'paramList'}{'-allowLists'} eq 'no')
-    {
-	my $err = "detected the following not allowed list parameters:\n\t<" .
-	    join('> <', @parList) . ">\n$Help";
-	&ConfigFile::printDie($err, $prLog);
-    }
-
+    die "detected the following not allowed list parameters:\n\t<",
+    join('> <', @parList), ">\n$Help"
+	if (@parList > 0 and $self->{'paramList'}{'-allowLists'} eq 'no');
     # map list parameters
     my $map = $self->{'paramList'}{'-listMapping'};
     if ($map)
     {
 	my $o = $self->{'namePointer'}{$map};
-	unless ($o)
-	{
-	    my $err = "-listMapping object <$map> does not exist";
-	    &ConfigFile::printDie($err, $prLog);
-	}
+	die "-listMapping object <$map> does not exist"
+	    unless $o;
+
 	if (defined($optWithPar{$map}) and $optWithPar{$map}{'value'})
 	{
 	    (@parList) = (@{$optWithPar{$map}{'value'}})
@@ -1166,23 +1037,13 @@ sub check
 	{
 	    $o = $self->{'keysPointer'}{$u};
 	}
-	unless ($o)
-	{
-	    my $err = "you tried to --unset option <$u> which is not known\n$Help";
-	    &ConfigFile::printDie($err, $prLog);
-	}
+	die "you tried to --unset option <$u> which is not known\n$Help"
+	    unless $o;
 
-	if ($o->get('-must_be') eq 'yes')
-	{
-	    my $err ="cannot unset <$u>, because this option must be set\n$Help";
-	    &ConfigFile::printDie($err, $prLog);
-	}
-
-	if ($o->get('-priority') eq 'cf')
-	{
-	    my $err = "option <$u> cannot be unmasked from command line\n$Help";
-	    &ConfigFile::printDie($err, $prLog);
-	}
+	die "cannot unset <$u>, because this option must be set\n$Help"
+	    if $o->get('-must_be') eq 'yes';
+	die "option <$u> cannot be unmasked from command line\n$Help"
+	    if $o->get('-priority') eq 'cf';
 
 	my $name = $o->get('-name');
 
@@ -1208,19 +1069,13 @@ sub check
 
 	if ($o->get('-param') eq 'no')   # kein Parameter
 	{
-	    unless ($optWithoutPar{$name})
-	    {
-		my $err = "missing option <$name>\n$Help";
-		&ConfigFile::printDie($err, $prLog);
-	    }
+	    die "missing option <$name>\n$Help"
+		unless ($optWithoutPar{$name});
 	}
 	else # hat Parameter
 	{
-	    unless ($optWithPar{$name})
-	    {
-		my $err = "missing option with parameter <$name param>\n$Help";
-		&ConfigFile::printDie($err, $prLog);
-	    }
+	    die "missing option with parameter <$name param>\n$Help"
+		unless ($optWithPar{$name});
 	}
     }
 
@@ -1240,14 +1095,13 @@ sub check
 		{
 		    if ($o->get('-comment'))
 		    {
-			&ConfigFile::printDie($o->get('-comment'), $prLog);
+			die $o->get('-comment');
 		    }
 		    else
 		    {
-			my $err = "<" . $v .
-			    "> is not a valid value for option <$k>\nallowed pattern is " .
-			    "<$pat>\n$Help";
-			&ConfigFile::printDie($err, $prLog);
+			die "<", $v,
+			"> is not a valid value for option <$k>\nallowed pattern is ",
+			"<$pat>\n$Help";
 		    }
 		}
 	    }
@@ -1258,14 +1112,13 @@ sub check
 	    {
 		if ($o->get('-comment'))
 		{
-		    &ConfigFile::printDie($o->get('-comment'), $prLog);
+		    die $o->get('-comment');
 		}
 		else
 		{
-		    my $err = "<" . $optWithPar{$k}{'value'} .
-			"> is not a valid value for option <$k>\nallowed pattern is " .
-			"<$pat>\n$Help";
-		    &ConfigFile::printDie($err, $prLog);
+		    die "<", $optWithPar{$k}{'value'},
+		    "> is not a valid value for option <$k>\nallowed pattern is ",
+		    "<$pat>\n$Help";
 		}
 	    }
 	}
@@ -1300,14 +1153,13 @@ sub check
 	{
 	    if ($o->get('-comment'))
 	    {
-		&ConfigFile::printDie($o->get('-comment'), $prLog);
+		die $o->get('-comment');
 	    }
 	    else
 	    {
-		my $err = "illegal combination in use of option <" .
-		    $o->get('-name') . ">, rule = (" . $o->get('-only_if') .
-		    ")\n\t\t\t\t\t\t  <<$only_print>>\n$Help";
-		&ConfigFile::printDie($err, $prLog);
+		die "illegal combination in use of option <",
+		$o->get('-name'), ">, rule = (", $o->get('-only_if'),
+		")\n\t\t\t\t\t\t  <<$only_print>>\n$Help";
 	    }
 	}
     }
@@ -1333,12 +1185,9 @@ sub getOptNamesSet
 			 ['-type']);
 
     my $type = $params{'-type'};
-    unless ($type =~ /\AwithPar\Z|\AwithoutPar\Z/)
-    {
-	my $err = "type of CheckParam->getOptNames must be withPar or withoutPar";
-	my $prLog = $self->{'paramList'}{'-prLog'};
-	&ConfigFile::printDie($err, $prLog);
-    }
+    die "type of CheckParam->getOptNames must be withPar or withoutPar"
+	unless $type =~ /\AwithPar\Z|\AwithoutPar\Z/;
+
     my $opts = $self->{'Erg'}{$type};
     return sort keys %$opts;
 }
@@ -1350,7 +1199,7 @@ sub print
     my $self = shift;
 
     # Defaultwerte f"ur Parameter setzen
-    my (%params) = ('-showHidden' => 'no'    # 'yes' = show hidden
+    my (%params) = ('-showHidden' => 0    # 1 = show hidden
 	);
 
     &::checkObjectParams(\%params, \@_, 'CheckParam::print', []);
@@ -1408,18 +1257,11 @@ sub getOptWithPar
     my $self = shift;
     my $par = shift;
 
-    my $prLog = $self->{'paramList'}{'-prLog'};
+    die "option <$par> does not exist"
+	unless defined $self->{'namePointer'}{$par};
+    die "option <$par> does not have a parameter, use getOptWithoutPar"
+	unless $self->{'namePointer'}{$par}->get('-param') eq 'yes';
 
-    unless (defined $self->{'namePointer'}{$par})
-    {
-	my $err =  "option <$par> does not exist";
-	&ConfigFile::printDie($err, $prLog);
-    }
-    unless ($self->{'namePointer'}{$par}->get('-param') eq 'yes')
-    {
-	my $err = "option <$par> does not have a parameter, use getOptWithoutPar";
-	&ConfigFile::printDie($err, $prLog);
-    }
     my $r = $self->{'Erg'}{'withPar'}{$par}{'value'};
     if (ref($r) eq 'ARRAY')
     {
@@ -1434,18 +1276,11 @@ sub getOptWithoutPar
     my $self = shift;
     my $par = shift;
 
-    my $prLog = $self->{'paramList'}{'-prLog'};
+    die "option <$par> does not exist"
+	unless defined $self->{'namePointer'}{$par};
+    die "option <$par> has a parameter, use getOptWithPar"
+	unless $self->{'namePointer'}{$par}->get('-param') eq 'no';
 
-    unless (defined $self->{'namePointer'}{$par})
-    {
-	my $err = "option <$par> does not exist";
-	&ConfigFile::printDie($err, $prLog);
-    }
-    unless ($self->{'namePointer'}{$par}->get('-param') eq 'no')
-    {
-	my $err = "option <$par> has a parameter, use getOptWithPar";
-	&ConfigFile::printDie($err, $prLog);
-    }
     return $self->{'Erg'}{'withoutPar'}{$par};
 }
 
@@ -1465,16 +1300,6 @@ sub getNoListPar
     return scalar(@{$self->{'Erg'}{'listPar'}});
 }
 
-########################################
-# order of options in @ARGV, if one option is used multiple times
-# it's also multiple times in the list
-sub getOptOrder
-{
-    my $self = shift;
-
-    return @{$self->{'Erg'}{'optOrder'}};
-}
-
 
 ######################################################################
 # Iterator f"ur die List-Parameter
