@@ -1,7 +1,7 @@
 # -*- perl -*-
 
 #
-#   Copyright (C) Heinz-Josef Claes (2001-2020)
+#   Copyright (C) Heinz-Josef Claes (2001-2012)
 #                 hjclaes@web.de
 #
 #   This program is free software: you can redistribute it and/or modify
@@ -64,18 +64,17 @@ sub waitForFile
 
     my @intervall = (.01, .01, .02, .02, .04, .05, .05,
 		      .05, .05, .05, .05, .05, .05, .05, .05,
-		     .05, .05, .05, .05, .05, .05, .05, .05, 0); # 1 second
+		     .05, .05, .05, .05, .05, .05, .05, .05); # 1 second
 
-    if ((not -e $existingFile) or (stat($existingFile))[7] == 0)
+    if (not -e $existingFile)
     {
 	my $i;
 	foreach $i (@intervall)
 	{
 	    select(undef, undef, undef, $i);
-	    if (-e $existingFile and (stat($existingFile))[7] > 0)
+	    if (-e $existingFile)
 	    {
-		select(undef, undef, undef, 2 * $intervall[0]);
-#		system "/bin/sync";
+		select(undef, undef, undef, $intervall[0]);
 		last;
 	    }
 	}
@@ -83,7 +82,7 @@ sub waitForFile
 	if ($i == 0)
 	{
 	    system "/bin/sync";
-	    return ((not -e $existingFile) or (stat($existingFile))[7] == 0);
+	    return not -e $existingFile;
 	}
     }
 
@@ -91,46 +90,6 @@ sub waitForFile
 }
 
 
-############################################################
-sub detachFromTerminal
-{
-    my $prLog = shift;
-    my $verbose = shift;
-    my $pidfile = shift;
-
-    return if getppid() == 1;     # ist schon ein daemon
-
-    my $i = fork();
-    exit 0 if ($i == 0);           # child process beenden
-
-    unless (defined $i or POSIX::setsid())
-    {
-	unlink $pidfile if defined $pidfile;
-	$prLog->print('-kind' => 'E',
-		      '-str' => ["cannot daemonize, exiting"],
-		      '-exit' => 1);
-    }
-
-    my $i = fork();
-    exit 0 if ($i > 0);           # parent process beenden
-
-    ## Change working directory
-    chdir "/";
-
-    ## Clear file creation mask
-    umask 0;
-
-    ## Reopen stderr, stdout, stdin to /dev/null
-    open(STDIN,  "+>/dev/null");
-    open(STDOUT, "+>&STDIN");
-    open(STDERR, "+>&STDIN");
-
-    $prLog->print('-kind' => 'I',
-		  '-str' => ["daemonizing"])
-	if $verbose;
-}
-
-
 ############################################################
 package simpleFork;
 
@@ -272,17 +231,13 @@ sub new
     my $err = $params{'-prLogError'};
     my $ex = $params{'-exitIfError'};
 
-    die "use one options of <-outRandom> or <-stdout / -stderr> at" .
-	"__FILE__, __LINE__"
-	unless defined $outRandom or ($stdout and $stderr);
-
     # zufllig Dateinamen erstellen, falls ntig
-    if (defined $outRandom)
+    if ($outRandom ne undef)
     {
 	$self->{'stdout'} = $stdout = &::uniqFileName($outRandom)
-	    unless defined $stdout;
+	    if $stdout eq undef;
 	$self->{'stderr'} = $stderr = &::uniqFileName($outRandom)
-	    unless defined $stderr;
+	    if $stderr eq undef;
     }
 
     my $child;
@@ -697,7 +652,7 @@ sub new
 		    '-delStdout'   => 'yes', # lsche Datei fr stdout
 		                             # automatisch
 
-		    '-prLog'       => undef, # if not set, uses STDERR
+		    '-prLog'       => undef,
 
 		    '-info'        => undef, # beliebige zustzliche Info
 
@@ -706,7 +661,7 @@ sub new
 		    );
 
     &::checkObjectParams(\%params, \@_, 'forkProc::new',
-			 ['-exec']);
+			 ['-exec', '-prLog']);
     &::setParamsDirect($self, \%params);
 
     my $proc = $params{'-exec'};
@@ -721,12 +676,12 @@ sub new
     my $ex = $params{'-exitIfError'};
 
     # zufllig Dateinamen erstellen, falls ntig
-    if (defined $outRandom)
+    if ($outRandom ne undef)
     {
 	$self->{'stdout'} = $stdout = &::uniqFileName($outRandom)
-	    unless defined $stdout;
+	    if $stdout eq undef;
 	$self->{'stderr'} = $stderr = &::uniqFileName($outRandom)
-	    unless defined $stderr;
+	    if $stderr eq undef;
     }
 
     # jetzt forken
@@ -737,16 +692,9 @@ sub new
 	{
 	    unless (chdir "$dir")
 	    {
-		if ($prLog)
-		{
-		    $prLog->print('-kind' => $err,
-				  '-str' =>
-				  ["Cannot chdir to <$dir> for <$proc>"]);
-		}
-		else
-		{
-		    print STDERR "Cannot chdir to <$dir> for <$proc>\n";
-		}
+		$prLog->print('-kind' => $err,
+			      '-str' =>
+			      ["Cannot chdir to <$dir> for <$proc>"]);
 		exit $ex;
 	    }
 	}
@@ -754,16 +702,9 @@ sub new
 	{
 	    unless (sysopen(STDIN, $stdin, 0))
 	    {
-		if ($prLog)
-		{
-		    $prLog->print('-kind' => $err,
-				  '-str' =>
-				  ["Cannot read <$stdin> when starting <$proc>"]);
-		}
-		else
-		{
-		    print STDERR "Cannot read <$stdin> when starting <$proc>\n";
-		}
+		$prLog->print('-kind' => $err,
+			      '-str' =>
+			      ["Cannot read <$stdin> when starting <$proc>"]);
 		exit $ex;
 	    }
 	}
@@ -771,16 +712,9 @@ sub new
 	{
 	    unless (open STDOUT, "> $stdout")
 	    {
-		if ($prLog)
-		{
-		    $prLog->print('-kind' => $err,
-				  '-str' =>
-				  ["Cannot write <$stdout> when starting <$proc>"]);
-		}
-		else
-		{
-		    print STDERR "Cannot write <$stdout> when starting <$proc>\n";
-		}
+		$prLog->print('-kind' => $err,
+			      '-str' =>
+			      ["Cannot write <$stdout> when starting <$proc>"]);
 		exit $ex;
 	    }
 	    chown 0600, $stdout;
@@ -789,32 +723,19 @@ sub new
 	{
 	    unless (open STDERR, "> $stderr")
 	    {
-		if ($prLog)
-		{
-		    $prLog->print('-kind' => $err,
-				  '-str' =>
-				  ["Cannot dup stderr when starting $proc"]);
-		}
-		else
-		{
-		    print STDERR "Cannot dup stderr when starting $proc\n";
-		}
+		$prLog->print('-kind' => $err,
+			      '-str' =>
+			      ["Cannot dup stderr when starting $proc"]);
 		exit $ex;
 	    }
 	    chown 0600, $stderr;
 	}
 
+	$proc =~ s/(\s)/\\$1/g;
 	unless (exec $proc, @$par)
 	{
-	    if ($prLog)
-	    {
-		$prLog->print('-kind' => $err,
-			      '-str' => ["cannot exec $proc @$par"]);
-	    }
-	    else
-	    {
-		print STDERR "cannot exec $proc @$par\n";
-	    }
+	    $prLog->print('-kind' => $err,
+			  '-str' => ["cannot exec $proc @$par"]);
 	    exit $ex;
 	}
     }
@@ -929,18 +850,10 @@ sub signal
 
     my $ret = kill $params{'-value'}, $self->{'pid'};
 
-    if ($ret)
-    {
-	if ($self->{'prLog'})
-	{
-	    $self->{'prLog'}->print(-kind => 'W',
-				    -str =>
-				    ["signaling process " . $self->{'pid'}]);
-	}
-	else
-	{
-	    print STDERR "signaling process " . $self->{'pid'} . "\n";
-	}
+    if ($ret) {
+	$self->{'prLog'}->print(-kind => 'W',
+				-str =>
+				["signaling process " . $self->{'pid'}]);
 	$self->delSTDOUT();
     }
     return $ret;
@@ -1135,7 +1048,8 @@ sub add_block
     my $sched =
 	tinyWaitScheduler->new('-firstFast'     => $self->{'firstFast'},
 			       '-noOfWaitSteps' => $self->{'noOfWaitSteps'},
-			       '-prLog'         => $self->{'prLog'});
+			       '-prLog'         => $self->{'prLog'},
+			       '-noOfWaitSteps' => 10);
 
     my $old;
     $sched->wait() until
@@ -1274,10 +1188,10 @@ sub new
     my $self = {};
 
     my (%params) = ('-maxWaitTime'   => 1,     # in seconds (-> add())
-		    '-noOfWaitSteps' => 100,
+		    '-noOfWaitSteps' => 10,
 		    '-firstFast'     => 1,     # falls 1, beim ersten Mal nicht warten
                     '-debug'         => 0,
-                    '-prLog'         => undef
+                    '-prLog'         => undef,
                    );
 
     &::checkObjectParams(\%params, \@_, 'tinyWaitScheduler::new',
