@@ -1,7 +1,7 @@
 #! /usr/bin/perl
 
 #
-#   Copyright (C) Heinz-Josef Claes (2009-2020)
+#   Copyright (C) Heinz-Josef Claes (2009-2012)
 #                 hjclaes@web.de
 #
 #   This program is free software: you can redistribute it and/or modify
@@ -21,8 +21,6 @@
 use Fcntl;
 use Digest::MD5 qw(md5_hex);
 
-use POSIX;
-use POSIX ":sys_wait_h";
 
 # $0 comprProg fileToRead fileToSave md5RetFile
 # ret:
@@ -32,8 +30,7 @@ use POSIX ":sys_wait_h";
 #   3 cannot write md5sum
 
 
-
-my ($comprProg, $fileToRead, $fileToSave, $md5RetFile, $tmpdir,
+my ($comprProg, $fileToRead, $fileToSave, $md5RetFile,
     @comprProgFlags) = @ARGV;
 
 
@@ -43,77 +40,57 @@ unless (sysopen(IN, $fileToRead, O_RDONLY))
     exit 1;
 }
 
-my $prefix = "$tmpdir/stbu-md5Exec-";
-my $suffix;
-do
+unless (pipe_to_fork('COMP', $fileToSave, [$comprProg, @comprProgFlags]))
 {
-    $suffix = sprintf '%08x%08x', rand 0xffffffff, rand 0xffffffff;
+    print STDERR "cannot exec <$comprProg> (", __FILE__, " ", __LINE__,  ")\n";
+    exit 2;
 }
-while (-e $prefix . $suffix);
-my $stderr = $prefix . $suffix;
-
-
-local *PARENT;
-my $fd = *PARENT;
-
-my $child;
-pipe $child, $fd or die "pipe failed: $!";
-my $pid = fork();
-die "fork() failed: $!" unless defined $pid;
-if ($pid == 0) # in the parent
-{
-    close $Child;
-}
-elsif ($pid < 0)
-{
-    die "failed to fork in $0\n";
-}
-else  # in the child
-{
-    close PARENT;
-    open(STDERR, ">", $stderr)
-	or die "cannot open STDERR";
-    open(STDIN, "<&=" . fileno($child))
-	or die "cannot open STDIN";
-    open(STDOUT, ">", $fileToSave)
-	or die "cannot open STDOUT";
-
-    exec($comprProg, @comprProgFlags);
-    die "couldn't exec $comprProg @comprProgFlags";
-}
-
-
 chmod 0700, $fileToSave;
-if (-s $stderr)      # file exists and is > 0
-{
-    open(ERR, "<", $stderr)
-	or print STDERR "cannot open <$stderr> in $0";
-    my (@err) = <ERR>;
-    close(ERR);
-    print STDERR "@err";
-}
-unlink $stderr;
 
 my $md5 = Digest::MD5->new();
 my ($buffer, $n, $size);
 $size = 0;
 while ($n = sysread(IN, $buffer, 4096))
 {
-    print STDERR "cannot write to <$fileToSave>\n"
-	unless syswrite $fd, $buffer;
+    syswrite COMP, $buffer;
     $md5->add($buffer);
     $size += $n;
 }
-close($fd);
+close(COMP);
 close(IN);
-waitpid $pid, 0;
 
-unless (open(MD5, '>', $md5RetFile))
-{
-    print STDERR "cannot write to <$md5RetFile>\n";
-    exit 3;
-}
+open(MD5, '>', $md5RetFile)
+    or exit 3;
 print MD5 $md5->hexdigest(), "\n$size\n";
 close(MD5);
 
 exit 0;
+
+
+########################################
+sub pipe_to_fork
+{
+    my $parent = shift;
+    my $stdout = shift;
+    my $execProc = shift;   # proc + params in []
+
+    my $child;
+    pipe $child, $parent or die "pipe failed: $!";
+    my $pid = fork();
+    die "fork() failed: $!" unless defined $pid;
+    if ($pid) # in the parent
+    {
+	close $child;
+    }
+    else  # in the client
+    {
+	close $parent;
+	open(STDIN, "<&=" . fileno($child))
+	    or die "cannot open STDIN";
+	open(STDOUT, ">", $stdout)
+	    or die "cannot open STDOUT";
+
+	exec @$execProc;
+    }
+    $pid;
+}
