@@ -1,7 +1,7 @@
 # -*- perl -*-
 
 #
-#   Copyright (C) Heinz-Josef Claes (2002-2020)
+#   Copyright (C) Heinz-Josef Claes (2002-2012)
 #                 hjclaes@web.de
 #   
 #   This program is free software: you can redistribute it and/or modify
@@ -19,19 +19,19 @@
 #
 
 
-$main::STOREBACKUPVERSION = "3.5.1";
+$main::STOREBACKUPVERSION = "3.3";
 
 
 sub printVersion
 {
-    my ($ARGV, $par1, $par2) = @_;
+    my ($ARGV, $par) = @_;
 
     my ($flag) = 0;
     my ($entry);
 
     foreach $entry (@$ARGV)
     {
-	if ($entry eq $par1 or $entry eq $par2)
+	if ($entry eq $par)
 	{
 	    $flag = 1;
 	    last;
@@ -45,29 +45,4 @@ sub printVersion
 }
 
 
-##################################################
-# ignores everything after eg. 1.2.3
-# so '1.2.3 +' results in 1.002003
-sub calcOneVersionNumber
-{
-    my $asciiVersion = shift;
-
-    $asciiVersion =~ /\A(\d+)(.*)/;
-    my $ovn = $1;
-    $asciiVersion = $2;
-    my $count = 1;
-    while ($asciiVersion)
-    {
-	$asciiVersion =~ /\A\.(\d+)(.*)/;
-	if ($1)
-	{
-	    $ovn = $ovn + ($1 / 10**(3*$count));
-	    $asciiVersion = $2;
-	    ++$count;
-	}
-    }
-    return $ovn;
-}
-
-
 1
